<HTML>
<!--
FastPACS 
2006-2008 by Precision Diagnostic Systems, Inc.
Maple Park, IL 60151 USA

Based on the copyrighted work of Takaya Sakusabe

On-Line Support
Contents copyright Precision Diagnostic Systems, Inc.
Maple Park, IL 60151 USA
-->
<%@ Import Namespace="System.Xml" %>
<%@ Import Namespace="System.Globalization" %>
<%@ Import Namespace="DIOWave" %>
<%@ Import Namespace="System.IO" %>
<script src="classes.cs" runat="server" />
<script src="viewer-common.cs" runat="server" />
<script src="viewer-custom.cs" runat="server" />
<script runat="server">
//========================================================================================

	//==============================
	// QueryStringValue Class
	//==============================
	const UInt32 kImageSpacing = 4;

	//==============================
	// QueryStringValue Class
	//==============================
	class QueryStringValue : QueryStringValueBase {
	
		public readonly String volume;
		public readonly String path;
		public readonly String series_uid;
		public readonly UInt32 window_width;
		public readonly UInt32 window_height;
		public readonly String fit;
		public readonly String layout;
		public readonly String order;
		public readonly String voi;
		public readonly Single zoom;
		public readonly Int32 zx;
		public readonly Int32 zy;
		public readonly String action;
		public readonly String overlay;
		public readonly Int32 first_index;

		public readonly bool bad;

		public QueryStringValue(HttpRequest req, BrowserCheck browser, StringDictionary pref)
			: base(req) {

			UInt32 width_margin = 2;
			UInt32 height_margin = 2;

			if (browser.type == "NN") {
				if (browser.os == "M") {
					width_margin = 8;
					height_margin = 8;
				} else if (browser.os == "W") {
					width_margin = 4;
					height_margin = 4;
				}
			} else if (browser.type == "IE") {
				if (browser.os == "M") {
					width_margin = 16;
					height_margin = 16;
				}
			}
	
			this.volume = get_opt_str("VOLUME", null);
			this.path = get_opt_str("PATH", null);
			this.series_uid = get_opt_str("SERIES", null);
			this.window_width = (UInt32)(get_opt_int("WW", 600) - width_margin);
			this.window_height = (UInt32)(get_opt_int("WH", 400) - height_margin);

			this.voi = get_opt_str("VOI", null);
			this.zoom = Single.Parse(get_opt_str("ZOOM", "1.0"));
			this.zx = get_opt_int("ZX", -1);
			this.zy = get_opt_int("ZY", -1);
			this.first_index = get_opt_int("FI", -1);

			this.layout = get_val("LAYOUT", pref, default_layout, null);
			this.fit = get_val("FIT", pref, default_fit, "2");
			this.order = get_val("ORDER", pref, default_order, "N,A");
			this.overlay = get_val("OVERLAY", pref, default_overlay, "D");
			this.action = get_val("ACTION", pref, default_action, "P");
	
			this.bad = this.volume == null || this.path == null || this.series_uid == null;
		}

	}

	//==============================
	//
	//==============================
	DicomStudy loadDOM(QueryStringValue qsv, XmlDocument config_dom) {
		String volume = qsv.volume;
		String path = qsv.path;
		String series_uid = qsv.series_uid;

		DicomStudy dom = null;
		StudyCache dw_obj = (StudyCache)Application.Get("StudyDOM");
		XmlNode vol = config_dom.SelectSingleNode("/DIOWaveConfiguration/VOLUME[@label=\"" + volume + "\"]");
		String dir = vol.SelectSingleNode("directory").InnerText;
		String studyLoc = vol.SelectSingleNode("location").InnerText + "/" + path;
		if (dir.StartsWith("\\")) {
			dom = dw_obj.GetRemoteDicomStudy("http://localhost/DIOWave/scripts/dio-study.isa" + studyLoc);
		} else {
			dom = dw_obj.GetDicomStudy(studyLoc);
		}

		DataElementObject series_uid_obj = null;
		foreach (DataElementObject deo in dom.el) {
			if (deo.tag != 0x0020000E)
				continue;
			if ((String)deo.value != series_uid)
				continue;
			series_uid_obj = deo;
			break;
		}
		if (series_uid_obj == null)
			return null;

		ArrayList new_fl = new ArrayList();
		foreach (SOPInstanceObject f in dom.fl) {
			bool found = false;
			foreach (DataElementObject deo in f.data) {
				if (deo.tag < 0x0020000E)
					continue;
				else if (deo.tag > 0x0020000E)
					break;
				if (deo != series_uid_obj)
					continue;
				found = true;
				break;
			}
			if (found) {
				new_fl.Add(f);
			}
		}
		dom.fl = new_fl;

		return dom;
	}

	//==============================
	//
	//==============================
	void print_study_info_ex(DicomStudy dom, UInt32 num_images) {	
		Writer.Write("#" + get_data_IS(null, dom, 0x00200011, String.Empty) + " [" + num_images + "]");
	}

	//==============================
	// Sort Image List
	//==============================
	void sortImageList(ArrayList IL, String orderKey) {
	
		String[] ok = orderKey.Split(new Char[] {','});
		if (ok.Length != 2) {
			ok[0] = "N";
			ok[1] = "A";
		}
	
		switch (ok[0]) {
		case "N":
			if (ok[1] == "A")
				IL.Sort(new compImageNumberA());
			else
				IL.Sort(new compImageNumberD());
			return;
		case "T":
			if (ok[1] == "A")
				IL.Sort(new compImageTimeA());
			else
				IL.Sort(new compImageTimeD());
			return;
		case "Z":
			if (ok[1] == "A")
				IL.Sort(new compImagePositionZA());
			else
				IL.Sort(new compImagePositionZD());
			return;
		case "Y":
			if (ok[1] == "A")
				IL.Sort(new compImagePositionYA());
			else
				IL.Sort(new compImagePositionYD());
			return;
		case "X":
			if (ok[1] == "A")
				IL.Sort(new compImagePositionXA());
			else
				IL.Sort(new compImagePositionXD());
			return;
		default:
			IL.Sort(new compImageNumberA());
			return;
		}
	}

	//==============================
	// Image Comparison Functions
	//==============================
	//==============================
	class compImageNumberA : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareNumber((ImageObject)oa, (ImageObject)ob);
		}
	}
	//==============================
	class compImageNumberD : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareNumber((ImageObject)ob, (ImageObject)oa);
		}
	}
	//==============================
	class compImageTimeA : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareDateTime((ImageObject)oa, (ImageObject)ob);
		}
	}
	//==============================
	class compImageTimeD : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareDateTime((ImageObject)ob, (ImageObject)oa);
		}
	}
	//==============================
	class compImagePositionZA : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareZ((ImageObject)oa, (ImageObject)ob);
		}
	}
	//==============================
	class compImagePositionZD : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareZ((ImageObject)ob, (ImageObject)oa);
		}
	}
	//==============================
	class compImagePositionYA : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareY((ImageObject)oa, (ImageObject)ob);
		}
	}
	//==============================
	class compImagePositionYD : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareY((ImageObject)ob, (ImageObject)oa);
		}
	}
	//==============================
	class compImagePositionXA : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareX((ImageObject)oa, (ImageObject)ob);
		}
	}
	//==============================
	class compImagePositionXD : IComparer {
		public int Compare(Object oa, Object ob) {
			return ImageObject.compareX((ImageObject)ob, (ImageObject)oa);
		}
	}

	//==============================
	//
	//==============================
	void printImageList(ArrayList image_list, ImageSpaceObject s) {

		Writer.Write("var IL = new Array(" + image_list.Count + ");\n");
		UInt32 i = 0;
		foreach (ImageObject img in image_list)
			Writer.Write("IL[" + i++ + "] = new IR(" + img.new_args(s) + ");\n");
	}

	//==============================
	//
	//
	//
	//==============================
	class LayoutEntry {
		public readonly UInt32 rows, cols;
		public readonly UInt32 pages;
		public readonly UInt32 width, height;
		public readonly UInt32 num_images;
		public readonly Double scale;

		//==============================
		//
		//==============================
		public LayoutEntry(UInt32 rows, UInt32 cols, Double scale, UInt32 pages, UInt32 width, UInt32 height) {
			this.rows = rows;
			this.cols = cols;
			this.scale = scale;
			this.pages = pages;
			this.width = width;
			this.height = height;
			this.num_images = rows * cols;
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class LayoutTableObject {

		//==============================
		//
		//
		//
		//==============================
		abstract class LayoutGenerator {
			protected UInt32 canvasWidth, canvasHeight, imageHeight, imageWidth, numImages;

			//==============================
			//
			//==============================
			public LayoutGenerator(UInt32 cw, UInt32 ch, UInt32 ih, UInt32 iw, UInt32 ni) {
				canvasWidth = cw;
				canvasHeight = ch;
				imageHeight = ih;
				imageWidth = iw;
				numImages = ni;
			}

			//==============================
			//
			//==============================
			public abstract LayoutEntry Gen(UInt32 rows, UInt32 cols);
		}

		//==============================
		//
		//
		//
		//==============================
		class FitLayout : LayoutGenerator {

			//==============================
			//
			//==============================
			public FitLayout(UInt32 cw, UInt32 ch, UInt32 ih, UInt32 iw, UInt32 ni)
				: base(cw, ch, ih, iw, ni) {}

			//==============================
			//
			//==============================
			public override LayoutEntry Gen(UInt32 rows, UInt32 cols) {
				UInt32 fit_factor = 8;
				UInt32 pages = (UInt32)Math.Ceiling((Double)numImages / (Double)(rows * cols));
				UInt32 width =  (UInt32)Math.Floor((Double)(canvasWidth - kImageSpacing * (cols - 1)) / (Double)cols / (Double)fit_factor) * fit_factor;
				UInt32 height = (UInt32)Math.Floor((Double)(canvasHeight - kImageSpacing * (rows - 1)) / (Double)rows / (Double)fit_factor) * fit_factor;
				Double xscale = (Double)width / (Double)imageWidth;
				Double yscale = (Double)height / (Double)imageHeight;
				Double scale = Math.Min(xscale, yscale);
				width = (UInt32)Math.Ceiling(imageWidth * scale);
				height = (UInt32)Math.Ceiling(imageHeight * scale);
		
				return new LayoutEntry(rows, cols, scale, pages, width, height);
			}
		}

		//==============================
		//
		//
		//
		//==============================
		class TwoLayout : LayoutGenerator {

			//==============================
			//
			//==============================
			public TwoLayout(UInt32 cw, UInt32 ch, UInt32 ih, UInt32 iw, UInt32 ni)
				: base(cw, ch, ih, iw, ni) {}

			//==============================
			//
			//==============================
			Double calc_scale2(Double in_scale) {
				Double out_scale = 1.0;
				if (in_scale < out_scale)
					while (in_scale < out_scale)
						out_scale /= 2;
				else if (in_scale > out_scale)
					while (in_scale > out_scale * 2)
						out_scale *= 2;
				return out_scale;
			}

			//==============================
			//
			//==============================
			public override LayoutEntry Gen(UInt32 rows, UInt32 cols) {
				UInt32 pages = (UInt32)Math.Ceiling(Convert.ToDouble(numImages / (rows * cols)));
				Double yscale = calc_scale2((Double)(canvasHeight - kImageSpacing * (rows - 1)) / (Double)(imageHeight * rows));
				Double xscale = calc_scale2((Double)(canvasWidth - kImageSpacing * (cols - 1)) / (Double)(imageWidth * cols));
				Double scale = Math.Min(xscale, yscale);
				UInt32 width = (UInt32)Math.Ceiling((Double)imageWidth * scale);
				UInt32 height = (UInt32)Math.Ceiling((Double)imageHeight * scale);
		
				return new LayoutEntry(rows, cols, scale, pages, width, height);
			}
		}

		public readonly ArrayList table;
		public readonly LayoutEntry layout;
		public readonly Boolean noscroll;

		//==============================
		//
		//==============================
		public LayoutTableObject(DicomStudy dom, QueryStringValue qsv, UInt32 num_images) {

			LayoutGenerator lg;
			if (qsv.fit == "F")
				lg = new FitLayout(qsv.window_width - kStripWidth, qsv.window_height - kInfoBarHeight - kMenuBarHeight, get_data_US(null, dom, 0x00280010, 0), get_data_US(null, dom, 0x00280011, 0), num_images);
			else
				lg = new TwoLayout(qsv.window_width - kStripWidth, qsv.window_height - kInfoBarHeight - kMenuBarHeight, get_data_US(null, dom, 0x00280010, 0), get_data_US(null, dom, 0x00280011, 0), num_images);

			table = new ArrayList();
	
			table.Add(lg.Gen(1, 1));
			
			table.Add(lg.Gen(2, 1));
			table.Add(lg.Gen(1, 2));
			
			table.Add(lg.Gen(2, 2));
			
			table.Add(lg.Gen(3, 2));
			table.Add(lg.Gen(2, 3));
			
			table.Add(lg.Gen(3, 3));
			
			table.Add(lg.Gen(4, 3));
			table.Add(lg.Gen(3, 4));
			
			table.Add(lg.Gen(4, 4));
			
			table.Add(lg.Gen(5, 4));
			table.Add(lg.Gen(4, 5));

			this.layout = null;
			if (qsv.layout != null) {
				String[] rc = qsv.layout.Split(new Char[] {','});
				UInt32 r = UInt32.Parse(rc[0]);
				UInt32 c = UInt32.Parse(rc[1]);
				if (r * c > num_images)
					r = (UInt32)((num_images / c) + (num_images % c == 0 ? 0 : 1));
				foreach (LayoutEntry lo in table) {
					if (lo.rows == r && lo.cols == c) {
						this.layout = lo;
						break;
					}
				}
			}
			if (this.layout == null) {
				ArrayList scoreArray = new ArrayList();
				foreach (LayoutEntry lo in table) {
					UInt32 laycount = lo.rows * lo.cols;
					if (laycount > num_images)
						break;
					if (laycount > 12)
						break;
					scoreArray.Add(lo.width * lo.height * laycount);
				}
				UInt32 max = 0;
				int index = 0;
				for (int i = 0; i < scoreArray.Count; i++) {
					UInt32 score = (UInt32)scoreArray[i];
					if (max == 0) {
						max = score;
					} else if (score >= max) {
						max = score;
						index = i;
					}
				}
				this.layout = (LayoutEntry)table[index];
			}

			this.noscroll = num_images <= (this.layout.rows * this.layout.cols);

		}

		//==============================
		//
		//==============================
		public LayoutEntry this[int index] {
			get { return (LayoutEntry)table[index]; }
		}

	}

	//==============================
	//
	//==============================
	class SliderPanelObject {

		public readonly Double icon_step;
		public readonly UInt32 num_icons;
		public readonly UInt32 panel_height;

		public readonly UInt32 ind_height;
		public readonly Double ind_step;

		public SliderPanelObject(QueryStringValue qsv, UInt32 numImages, LayoutTableObject layoutTable) {

			UInt32 height = qsv.window_height - kInfoBarHeight - kMenuBarHeight;
			UInt32 width = kStripWidth;
			UInt32 numImageBox = layoutTable.layout.num_images;

			UInt32 panel_height = height / 2 - width;
	
			UInt32 numIcons = numImages;
			if (numIcons * width > panel_height)
				numIcons = (UInt32)Math.Ceiling((Double)panel_height / (Double)width);
	
			Double step = 1.0;
			if (numIcons != numImages && numIcons > 1)
				step = (numImages - 1) / (numIcons - 1);
	
			this.icon_step = numImages / numIcons;
			this.num_icons = numIcons;
			this.panel_height = numIcons * width;
		
			if (layoutTable.noscroll) {
				this.ind_height = this.panel_height;
				this.ind_step = 0;
			} else {
				this.ind_height = (UInt32)Math.Floor((Double)this.panel_height * ((Double)numImageBox / (Double)numImages));
				this.ind_step = (Double)(this.panel_height - this.ind_height) / (Double)(numImages - numImageBox);
			}
		}
	}

	//==============================
	//
	//==============================
	void printStrip(UInt32 height, UInt32 width, UInt32 numImages, SliderPanelObject sliderPanel, QueryStringValue qsv) {
		if (numImages == 1) {
			Writer.Write("<TABLE ALIGN='CENTER' HSPACE='0' VSPACE='0' CELLPADDING='0' CELLSPACING='0' BORDER='0' WIDTH='" + width + "' HEIGHT='" + height + "'><TR><TD>");
			Writer.Write("<IMG SRC='/DIOWave/grayscale.gif' HEIGHT='" + height + "' WIDTH='" + width + "' BORDER='0' HSPACE='0' VSPACE='0'>");
			Writer.Write("</TD></TR></TABLE>\n");
			return;
		}
	
		Writer.Write("<TABLE ALIGN='CENTER' HSPACE='0' VSPACE='0' CELLPADDING='0' CELLSPACING='0' BORDER='0' WIDTH='" + width + "' HEIGHT='" + height + "'>\n");
	
		Writer.Write("<TR><TD CLASS='ARROW' HEIGHT='" + (width / 2).ToString() + "'><A HREF='javascript:Jump(-1);'><IMG BORDER='0' WIDTH='" + width + "' HEIGHT='" + (width / 2).ToString() + "' SRC='/DIOWave/uparrow.gif'></A></TD></TR>\n");
		Writer.Write("<TR><TD CLASS='ARROW' HEIGHT='" + (width / 2).ToString() + "'><A HREF='javascript:Jump(1);'><IMG BORDER='0' WIDTH='" + width + "' HEIGHT='" + (width / 2).ToString() + "' SRC='/DIOWave/downarrow.gif'></A></TD></TR>\n");
	
		for (int i = 0; i < sliderPanel.num_icons; i++) {
			Writer.Write("<TR><TD>");
	
			if (i == 0) {
				if (m_browser.type == "NN") {
					Writer.Write("<ILAYER ID='SLIDER-ANC' TOP='0' LEFT='0' WIDTH='0' HEIGHT='0' Z-INDEX='0' VISIBILITY='HIDDEN'></ILAYER>");
					Writer.Write("<LAYER ID='SLIDER-IND' TOP='" + (kInfoBarHeight + kMenuBarHeight + kStripWidth) + "' LEFT='" + (qsv.window_width - kStripWidth) + "' HEIGHT='0' WIDTH='0' Z-INDEX='1' VISIBILITY='HIDDEN' CLASS='SLIDER-IND'></LAYER>");
					Writer.Write("<LAYER ID='SLIDER-ACT' TOP='" + (kInfoBarHeight + kMenuBarHeight + kStripWidth) + "' LEFT='" + (qsv.window_width - kStripWidth) + "' HEIGHT='" + sliderPanel.panel_height + "' WIDTH='" + width + "' Z-INDEX='2' CLASS='SLIDER-ACT'></LAYER>");
				} else if (m_browser.type == "IE" && m_browser.os == "W") {
					Writer.Write("<DIV ID='SLIDER-IND' CLASS='SLIDER-IND'></DIV>");
					Writer.Write("<DIV ID='SLIDER-ACT' CLASS='SLIDER-ACT'>");
					if (m_browser.version >= 5.5)
						Writer.Write("<TABLE ALIGN='CENTER' HSPACE='0' VSPACE='0' CELLPADDING='0' CELLSPACING='0' BORDER='0' WIDTH='100%' HEIGHT='100%'><TR><TD></TD</TR></TABLE>");
					Writer.Write("</DIV>");
				}
			}
	
			UInt32 index = (UInt32)Math.Floor((Double)i * sliderPanel.icon_step);
			Writer.Write("<IMG NAME='ICN-" + index + "' HEIGHT='" + width + "' WIDTH='" + width + "' BORDER='0' HSPACE='0' VSPACE='0' SRC='/DIOWave/bbox.gif'>");
	
			Writer.Write("</TD></TR>\n");
		}
	
		Writer.Write("<TR><TD><IMG SRC='/DIOWave/grayscale.gif' HEIGHT='" + (height - sliderPanel.panel_height - width) + "' WIDTH='" + width + "' BORDER='0' HSPACE='0' VSPACE='0'></TD></TR>\n");
	
		Writer.Write("</TABLE>");
	}

	//==============================
	//
	//==============================
	void printImageTable(LayoutEntry layout, UInt32 canvasHeight, UInt32 canvasWidth) {

		UInt32 tableWidth = layout.cols * layout.width + kImageSpacing * (layout.cols - 1);
		UInt32 tableHeight = layout.rows * layout.height + kImageSpacing * (layout.rows - 1);

		UInt32 hs = canvasWidth - tableWidth;
		UInt32 vs = canvasHeight - tableHeight;

		UInt32 hsl = (UInt32)Math.Floor((Double)hs / 2);
		UInt32 hsr = hs - hsl;

		UInt32 vst = (UInt32)Math.Floor((Double)vs / 2);
		UInt32 vsb = vs - vst;

		Writer.Write("<TABLE ALIGN='LEFT' HSPACE='0' VSPACE='0' CELLPADDING='0' CELLSPACING='0' BORDER='0' HEIGHT='" + canvasHeight + "' WIDTH='" + canvasWidth + "'>\n");

		if (vst > 0) {
			Writer.Write("<TR>\n");
			if (hsl > 0)
				Writer.Write("\t<TD HEIGHT='" + vst + "' WIDTH='" + hsl + "'></TD>\n");
			for (UInt32 c = 0; c < layout.cols; c++) {
				if (c > 0)
					Writer.Write("\t<TD HEIGHT='" + vst + "' WIDTH='" + kImageSpacing + "'></TD>\n");
				Writer.Write("\t<TD HEIGHT='" + vst + "' WIDTH='" + layout.width + "'></TD>\n");
			}
			if (hsr > 0)
				Writer.Write("\t<TD HEIGHT='" + vst + "' WIDTH='" + hsr + "'></TD>\n");
			Writer.Write("</TR>\n");
		}

		for (UInt32 r = 0; r < layout.rows; r++) {

			if (r > 0) {
				Writer.Write("<TR>\n");
				if (hsl > 0)
					Writer.Write("\t<TD HEIGHT='" + kImageSpacing + "' WIDTH='" + hsl + "'></TD>\n");
				for (UInt32 c = 0; c < layout.cols; c++) {
					if (c > 0)
						Writer.Write("\t<TD HEIGHT='" + kImageSpacing + "' WIDTH='" + kImageSpacing + "'></TD>\n");
					Writer.Write("\t<TD HEIGHT='" + kImageSpacing + "' WIDTH='" + layout.width + "'></TD>\n");
				}
				if (hsr > 0)
					Writer.Write("\t<TD HEIGHT='" + kImageSpacing + "' WIDTH='" + hsr + "'></TD>\n");
				Writer.Write("</TR>\n");
			}

			Writer.Write("<TR>\n");

			if (hsl > 0)
				Writer.Write("\t<TD HEIGHT='" + layout.height + "' WIDTH='" + hsl + "'></TD>\n");

			for (UInt32 c = 0; c < layout.cols; c++) {
				UInt32 index = layout.cols * r + c;

				if (c > 0)
					Writer.Write("\t<TD HEIGHT='" + layout.height + "' WIDTH='" + kImageSpacing + "'></TD>\n");

				Writer.Write("\t<TD HEIGHT='" + layout.height + "' WIDTH='" + layout.width + "'>");

				if (m_browser.type == "NN") {
					Writer.Write("<ILAYER ID='ANC-" + index + "' TOP='0' LEFT='0' WIDTH='0' HEIGHT='0' Z-INDEX='0' VISIBILITY='HIDDEN'></ILAYER>");
					Writer.Write("<LAYER ID='ANN-" + index + "' TOP='0' LEFT='0' HEIGHT='" + layout.height + "' WIDTH='" + layout.width + "' Z-INDEX='1' VISIBILITY='HIDDEN'></LAYER>");
					Writer.Write("<LAYER ID='ACT-" + index + "' TOP='0' LEFT='0' HEIGHT='" + layout.height + "' WIDTH='" + layout.width + "' Z-INDEX='2' VISIBILITY='HIDDEN'></LAYER>");
				} else if (m_browser.type == "IE" && m_browser.os == "W") {
					Writer.Write("<DIV ID='ANN-" + index + "' CLASS='ANN'></DIV>");
					Writer.Write("<DIV ID='ACT-" + index + "' CLASS='ACT'>");
					if (m_browser.version >= 5.5) {
						Writer.Write("<TABLE HSPACE='0' VSPACE='0' CELLPADDING='0' CELLSPACING='0' BORDER='0' WIDTH='100%' HEIGHT='100%'>");
						Writer.Write("<TR><TD ID='ACTTD-" + index + "'></TD></TR>");
						Writer.Write("</TABLE>");
					}
					Writer.Write("</DIV>");
				}

				Writer.Write("<IMG NAME='IMG-" + index + "' BORDER='0' HSPACE='0' VSPACE='0' WIDTH='" + layout.width + "' HEIGHT='" + layout.height + "' SRC='/DIOWave/bbox.gif'>");

				Writer.Write("</TD>\n");
			}

			if (hsr > 0)
				Writer.Write("\t<TD HEIGHT='" + layout.height + "' WIDTH='" + hsr + "'></TD>\n");

			Writer.Write("</TR>\n");
		}

		if (vsb > 0) {
			Writer.Write("<TR>\n");
			if (hsl > 0)
				Writer.Write("\t<TD HEIGHT='" + vsb + "' WIDTH='" + hsl + "'></TD>\n");
			for (UInt32 c = 0; c < layout.cols; c++) {
				if (c > 0)
					Writer.Write("\t<TD HEIGHT='" + vsb + "' WIDTH='" + kImageSpacing + "'></TD>\n");
				Writer.Write("\t<TD HEIGHT='" + vsb + "' WIDTH='" + layout.width + "'></TD>\n");
			}
			if (hsr > 0)
				Writer.Write("\t<TD HEIGHT='" + vsb + "' WIDTH='" + hsr + "'></TD>\n");
			Writer.Write("</TR>\n");
		}

		Writer.Write("</TABLE>");
	}


	//==========================
	//
	//==========================
	void print_pixel_info(SOPInstanceObject file) {
		int bitsStored = (int)get_data_US(file, null, 0x00280101, 0);
		int pixelRep = (int)get_data_US(file, null, 0x00280103, 0);

		Writer.Write("<NOBR>Bits Stored: <FONT COLOR='white'>" + bitsStored + " ");

		Writer.Write("[");
		if (pixelRep == 1)
			Writer.Write((-(1 << (bitsStored - 1))).ToString() + " .. " + ((1 << (bitsStored - 1)) - 1).ToString());
		else
			Writer.Write("0 .. " + ((1 << bitsStored) - 1).ToString());
		Writer.Write("]");

		Writer.Write("</FONT></NOBR>; \n");
	}

	//==========================
	//
	//==========================
	void print_image_dimensions(SOPInstanceObject file) {

		ArrayList pixelSpacing = get_data_array(file, null, 0x00280030);
		if (pixelSpacing != null && pixelSpacing.Count == 2) {
			try {
				Double psx = Double.Parse((String)pixelSpacing[0], DS_ns);
				Double psy = Double.Parse((String)pixelSpacing[1], DS_ns);
				Writer.Write("<NOBR>Spacing: <FONT COLOR='white'>" + psx.ToString("F3") + " x " + psy.ToString("F3") + "</FONT></NOBR>; \n");
			} catch (FormatException fe) {
				// maybe it is empty DS elements
				// prevent to throw the exception to caller
			}
		}
	
		String sliceThickness = get_data_DS(file, null, 0x00180050, null);
		if (sliceThickness != null) {
			try {
				Double val = Double.Parse(sliceThickness, DS_ns);
				Writer.Write("<NOBR>Thickness: <FONT COLOR='white'>" + val.ToString("F2") + "</FONT></NOBR>; \n");
			} catch (FormatException fe) {
				// maybe it is empty DS elements
				// prevent to throw the exception to caller
			}
		}
	
	}

	//==============================
	//
	//==============================
	void printSeriesDetail(DicomStudy dom, QueryStringValue qsv) {

		SOPInstanceObject file = (SOPInstanceObject)dom.fl[0];

		if (m_browser.type == "NN")
			Writer.Write("<LAYER CLASS='SeriesDetail' ID='SeriesDetail' VISIBILITY='HIDDEN' Z-INDEX='4' WIDTH='" + (qsv.window_width - kStripWidth - 2) + "'><FONT COLOR='#E0E0C0'>");
		else
			Writer.Write("<DIV CLASS='SeriesDetail' ID='SeriesDetail'>");

		print_pixel_info(file);
		print_image_dimensions(file);
	
		String modality = get_data_CS(file, dom, 0x00080060, null);
		if (modality == "MR") {
			print_desc_text(file, 0x00080008, "Image Type", 3);
			print_desc_text(file, 0x00181030, "Protocol Name", 0);
			print_desc_text(file, 0x0008103E, "Series Description", 0);
			print_desc_text(file, 0x00180010, "Contrast/Bolus Agent", 0);
			print_desc_text(file, 0x00185100, "Patient Position", 0);
			print_desc_text(file, 0x00180020, "Scanning Sequence", 0);
			print_desc_text(file, 0x00180021, "Sequence Variant", 0);
			print_desc_text(file, 0x00180022, "Scan Options", 0);
			print_desc_text(file, 0x00180023, "MR Acquisition Type", 0);
			print_desc_text(file, 0x00180024, "Sequence Name", 0);
			print_desc_text(file, 0x00180080, "Repetition Time", 0);
			print_desc_text(file, 0x00180081, "Echo Time", 0);
			print_desc_text(file, 0x00180082, "Inversion Time", 0);
			print_desc_text(file, 0x00100030, "Patient's DOB", 0);
			print_desc_text(file, 0x00101010, "Patient's Age", 0);
			print_desc_text(file, 0x00100040, "Sex", 0);
		} else if (modality == "CT") {
			print_desc_text(file, 0x00080008, "Image Type", 3);
			print_desc_text(file, 0x00181030, "Protocol Name", 0);
			print_desc_text(file, 0x0008103E, "Series Description", 0);
			print_desc_text(file, 0x00180010, "Contrast/Bolus Agent", 0);
			print_desc_text(file, 0x00185100, "Patient Position", 0);
			print_desc_text(file, 0x00180060, "KVP", 0);
			print_desc_text(file, 0x00180090, "Data Collection Diameter", 0);
			print_desc_text(file, 0x00180090, "Reconstruction Diameter", 0);
			print_desc_text(file, 0x00180022, "Scan Options", 0);
			print_desc_text(file, 0x00181140, "Rotation Direction", 0);
			print_desc_text(file, 0x00181160, "Filter Type", 0);
			print_desc_text(file, 0x00181190, "Focal Spot", 0);
			print_desc_text(file, 0x00181210, "Convolution Kernel", 0);
			print_desc_text(file, 0x00100030, "Patient's DOB", 0);
			print_desc_text(file, 0x00101010, "Patient's Age", 0);
			print_desc_text(file, 0x00100040, "Sex", 0);
		}
	
		if (m_browser.type == "NN")
			Writer.Write("</FONT><ILAYER></ILAYER></LAYER>\n");
		else
			Writer.Write("</DIV>\n");
	}

	//==============================
	//
	//==============================
	void printSeriesDetailButton() {
		if (m_browser.type == "NN")
			Writer.Write("<A STYLE='color:white;' HREF='javascript:void();' onClick='show_series_detail(); return true;'>Detail</A>");
		else
			Writer.Write("<A STYLE='color:white;' HREF='javascript:show_series_detail()'>Detail</A>");
	}

	//==============================
	//
	//
	//
	//==============================
	class LayoutMenu : MenuBase {

		//==============================
		//
		//==============================
		public LayoutMenu(LayoutTableObject layoutTable, QueryStringValue qsv) {

			this.table = new ArrayList();
			foreach (LayoutEntry layout in layoutTable.table)
				this.table.Add(new MenuItem(layout.rows.ToString() + "," + layout.cols.ToString(), layout.cols.ToString() + " X " + layout.rows.ToString() + " [" + (layout.width > layout.height ? layout.width : layout.height).ToString() + "]"));

			this.table.Add(new MenuItem(null, "---------"));

			this.table.Add(new MenuItem("2", bar("Scale of 2", qsv.fit == "2")));
			this.table.Add(new MenuItem("F", bar("Fit", qsv.fit == "F")));
		}

		//==============================
		//
		//==============================
		String bar(String str, bool flag) {
			if (flag)
				return "&lt; " + str + " &gt;";
			else
				return str;
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class VOIMenu : MenuBase {
		//==============================
		//
		//==============================
		public VOIMenu(VOITableObject voiTable) {
			this.table = new ArrayList();
			foreach (VOIEntry voi in voiTable.table)
				this.table.Add(new MenuItem(voi.wc.ToString() + "," + voi.ww.ToString(), voi.label));
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class OrderMenu : MenuBase {
		//==============================
		//
		//==============================
		public OrderMenu() {
			this.table = new ArrayList();
			this.table.Add(new MenuItem("N,A", "Num (N)"));
			this.table.Add(new MenuItem("N,D", "Num (R)"));
			this.table.Add(new MenuItem("T,A", "Time (N)"));
			this.table.Add(new MenuItem("T,D", "Time (R)"));
			this.table.Add(new MenuItem("Z,A", "Z (F-H)"));
			this.table.Add(new MenuItem("Z,D", "Z (H-F)"));
			this.table.Add(new MenuItem("Y,A", "Y (P-A)"));
			this.table.Add(new MenuItem("Y,D", "Y (A-P)"));
			this.table.Add(new MenuItem("X,A", "X (L-R)"));
			this.table.Add(new MenuItem("X,D", "X (R-L)"));
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class OverlayMenu : MenuBase {
		//==============================
		//
		//==============================
		public OverlayMenu() {
			this.table = new ArrayList();
			this.table.Add(new MenuItem("N", "Number"));
			this.table.Add(new MenuItem("D", "Detail"));
			this.table.Add(new MenuItem(".", "None"));
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class ZoomMenu : MenuBase {
		//==============================
		//
		//==============================
		public ZoomMenu() {
			this.table = new ArrayList();
			this.table.Add(new MenuItem("1", "X 1"));
			this.table.Add(new MenuItem("1.5", "X 1.5"));
			this.table.Add(new MenuItem("2", "X 2"));
			this.table.Add(new MenuItem("3", "X 3"));
			this.table.Add(new MenuItem("4", "X 4"));
			this.table.Add(new MenuItem("5", "X 5"));
			this.table.Add(new MenuItem("8", "X 8"));
			this.table.Add(new MenuItem("1", "X 10"));
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class ActionMenu : MenuBase {
		//==============================
		//
		//==============================
		public ActionMenu() {
			this.table = new ArrayList();
			this.table.Add(new MenuItem("P", "Page"));
			this.table.Add(new MenuItem("V", "W/L"));
			this.table.Add(new MenuItem("Z", "Zoom/Pan"));
			this.table.Add(new MenuItem(".", "None"));
		}
	}

//========================================================================================
</script>
<%
//========================================================================================

	setup(Request);
	Writer = Response.Output;

	QueryStringValue QSV = new QueryStringValue(Request, m_browser, (StringDictionary)Session["viewerpref"]);
	if (QSV.bad) {
		Response.Clear();
		Server.Transfer("/DIOWave/blank1.htm");
	}
	XmlDocument config_dom = (XmlDocument)Application.Get("DIOWaveConf");
	DicomStudy DOM = loadDOM(QSV, config_dom);

	ImageSpaceObject ImageSpace = new ImageSpaceObject();
	ArrayList ImageList = new ArrayList();
	foreach (SOPInstanceObject file in DOM.fl)
		ImageList.Add(new ImageObject(file, ImageSpace));
	ImageSpace.calc_center();
	sortImageList(ImageList, QSV.order);		

	UInt32 NumImages = (UInt32)DOM.fl.Count;
	LayoutTableObject LayoutTable = new LayoutTableObject(DOM, QSV, NumImages);
	VOITableObject VOITable = new VOITableObject(ImageSpace, DOM, QSV, VOIPresets(DOM));
	SliderPanelObject SliderPanel = new SliderPanelObject(QSV, NumImages, LayoutTable);

	DrMenu LayoutMenu = new DrMenu(Writer, m_browser, "Layout", "L", 102, new LayoutMenu(LayoutTable, QSV), "change_layout");
	DrMenu OrderMenu = new DrMenu(Writer, m_browser, "Sort", "S", 84, new OrderMenu(), "change_order");
	DrMenu OverlayMenu = new DrMenu(Writer, m_browser, "Overlay", "O", 64, new OverlayMenu(), "change_overlay");
	DrMenu VOIMenu = new DrMenu(Writer, m_browser, "Range", "V", 108, new VOIMenu(VOITable), "preset_voi");
	DrMenu ZoomMenu = new DrMenu(Writer, m_browser, "Zoom", "Z", 64, new ZoomMenu(), "zoom_changed");
	DrMenu ActionMenu = new DrMenu(Writer, m_browser, "Action", "A", 96, new ActionMenu(), "change_action");

//========================================================================================
%>
<HEAD>
<TITLE>Series Viewer</TITLE>
<META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset="utf-8">
</HEAD>
<SCRIPT LANGUAGE="JavaScript1.2">
//----------------------------------------------------------------------------------------
// Viewer independed code
//----------------------------------------------------------------------------------------
//------------------------------
//
//------------------------------
function prettyTime(time) {
	var str = new String(time);
	return str.substr(0, 2) + ':' + str.substr(2, 2) + ':' + str.substr(4, 4);
}

//------------------------------
//
//------------------------------
function round_ceil(v, f) {
	return (Math.ceil(v * f) / f).toString();
}

//------------------------------
// Image Object
//------------------------------
function IR(file, imageNumber, imageDate, imageTime, rows, cols, xs, ys, x, y, z, xd, yd, wc, ww) {
	this.file = file;
	this.number = imageNumber;
	this.date = imageDate;
	this.time = imageTime;
	this.rows = rows;
	this.cols = cols;
	this.xs = xs;
	this.ys = ys;
	this.x = x;
	this.y = y;
	this.z = z;
	this.xd = xd;
	this.yd = yd;
	this.wc = wc;
	this.ww = ww;
}

//------------------------------
//
//------------------------------
IR.prototype.uri = function() {
	return '/DIOWave/scripts/dio-image.isa'
	     + '<%=config_dom.SelectSingleNode("/DIOWaveConfiguration/VOLUME[@label=\"" + QSV.volume + "\"]/location").InnerText%>'
	     + '/'
	     + '<%=QSV.path%>'
	     + '/'
	     + this.file;
}

//------------------------------
// ImageBox
//------------------------------
function ImageBox(img, index) {
	this.img = img;
	this.index = index;
	this.loaded = true;
}
//------------------------------
//
//------------------------------
ImageBox.prototype.reload = function() {
	this.img.src = IDS.image_src(this.index, false);
}

//------------------------------
//
//------------------------------
ImageBox.prototype.start_track_update = function() {
	this.img.onload = onImageLoad;
	this.loaded = true;
}

//------------------------------
//
//------------------------------
ImageBox.prototype.track_update = function(nocache) {
	if (this.loaded) {
		this.loaded = false;
		this.img.src = IDS.image_src(this.index, nocache);
	}
}

//------------------------------
//
//------------------------------
ImageBox.prototype.end_track_update = function() {
	this.img.onload = null;
}

//------------------------------
//
//------------------------------
ImageBox.prototype.set_annotation = function() {
	set_annotation1(IDS.overlay, this.index);
}

//------------------------------
//
//------------------------------
function onActionMouseDown(e, action) {
<% if (m_browser.type == "IE") { %>
	e = window.event;
	if (e.button != 1 || e.shiftKey || e.altKey || e.ctlKey)
		return true;
<% } else if (m_browser.type == "NN") { %>
	if (e.which != 1 || (e.modifiers & (Event.ALT_MASK | Event.CONTROL_MASK | Event.SHIFT_MASK)) != 0)
		return true;
<% } else { %>
	if (e.altKey || e.ctrlKey || e.shiftKey || e.metaKey)
		return true;
<% } %>

	CurrentAction = action;
	CurrentAction.mousedown(e);
	CurrentAction.begin_drag(e);

<% if (m_browser.type == "IE") { %>
 	document.onmousemove = onDocumentMouseMove;
 	document.onmouseup = onDocumentMouseUp;
	e.cancelBubble = true;
<% } else if (m_browser.type == "NN") { %>
 	document.onMouseMove = onDocumentMouseMove;
 	document.onMouseUp = onDocumentMouseUp;
 	document.captureEvents(Event.MOUSEMOVE | Event.MOUSEUP);
<% } else { %>
 	document.onmousemove = onDocumentMouseMove;
 	document.onmouseup = onDocumentMouseUp;
<% } %>
	return false;
}

//------------------------------
//
//------------------------------
function onDocumentMouseUp(e) {
<% if (m_browser.type == "IE") { %>
	e = window.event;
<% } %>

	if (CurrentAction != null) {
		CurrentAction.end_drag(e);
		CurrentAction = null;
	}

<% if (m_browser.type == "IE") { %>
 	document.onmousemove = null;
 	document.onmouseup = null;
	e.cancelBubble = true;
<% } else if (m_browser.type == "NN") { %>
  	document.releaseEvents(Event.MOUSEMOVE | Event.MOUSEUP);
 	document.onMouseMove = null;
 	document.onMouseUp = null;
<% } else { %>
 	document.onmousemove = null;
 	document.onmouseup = null;
<% } %>
	return false;
}

//------------------------------
//
//------------------------------
function onDocumentMouseMove(e) {
<% if (m_browser.type == "IE") { %>
	e = window.event;
<% } %>

	if (CurrentAction != null)
		CurrentAction.do_drag(e);

<% if (m_browser.type == "IE") { %>
	e.cancelBubble = true;
<% } %>
	return false;
}

//------------------------------
// ImageActionObject
//------------------------------
function ImageActionObject() {
	this.md_imageX = -1;
	this.md_imageY = -1;
	this.md_pageX = -1;
	this.md_pageY = -1;

	this.mode = '.';

	this.anchor_x = -1;
	this.anchor_y = -1;
	this.anchor_X = -1;
	this.anchor_Y = -1;

	this.org_wc = -1;
	this.org_ww = -1;

	this.org_first_index = -1;

	this.box = null;
}

//------------------------------
//
//------------------------------
function ActionObject_mousedown(e) {
<% if (m_browser.type == "IE") { %>
 	this.md_imageX = e.offsetX;
	this.md_imageY = e.offsetY;
	this.md_pageX = e.clientX;
	this.md_pageY = e.clientY;
<% } else { %>
	this.md_imageX = e.layerX;
	this.md_imageY = e.layerY;
	this.md_pageX = e.pageX;
	this.md_pageY = e.pageY;
<% } %>
}
//------------------------------
ImageActionObject.prototype.mousedown = ActionObject_mousedown;

//------------------------------
//
//------------------------------
function ActionObject_x(e) {
<% if (m_browser.type == "IE") { %>
	return this.md_imageX + e.clientX - this.md_pageX;
<% } else { %>
	return this.md_imageX + e.pageX - this.md_pageX;
<% } %>
}
//------------------------------
ImageActionObject.prototype.x = ActionObject_x;

//------------------------------
//
//------------------------------
function ActionObject_y(e) {
<% if (m_browser.type == "IE") { %>
	return this.md_imageY + e.clientY - this.md_pageY;
<% } else { %>
	return this.md_imageY + e.pageY - this.md_pageY;
<% } %>
}
//------------------------------
ImageActionObject.prototype.y = ActionObject_y;

//------------------------------
//
//------------------------------
function ActionObject_offset_x(e) {
<% if (m_browser.type == "IE") { %>
	return e.clientX - this.md_pageX;
<% } else { %>
	return e.pageX - this.md_pageX;
<% } %>
}
//------------------------------
ImageActionObject.prototype.offset_x = ActionObject_offset_x;

//------------------------------
//
//------------------------------
function ActionObject_offset_y(e) {
<% if (m_browser.type == "IE") { %>
	return e.clientY - this.md_pageY;
<% } else { %>
	return e.pageY - this.md_pageY;
<% } %>
}
//------------------------------
ImageActionObject.prototype.offset_y = ActionObject_offset_y;

//------------------------------
//
//------------------------------
function onImageMouseDown(e) {
	return onActionMouseDown(e, ImageAction);
}

//------------------------------
//
//------------------------------
function SetVarText(id, val) {
<% if (m_browser.type == "NN") { %>
	var laydoc = document.layers[id].document.layers[0].document;
	laydoc.open('text/html', 'replace');
	laydoc.write(val);
	laydoc.close();
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>(id);
	div.<%=m_cfn.innerText%> = val;
<% } %>
}

//------------------------------
//
//------------------------------
function setVOIText() {
	var wc = IDS.wc;
	var ww = IDS.ww;
	if (wc == 0 && ww == 0) {
		wc = "";
		ww = "";
	}
	SetVarText('WC', wc);
	SetVarText('WW', ww);
}

//------------------------------
//
//------------------------------
function change_action(arg) {
	if (IDS.action == arg)
		return;
	IDS.action = arg;
	setActionText();
	setup_action(arg);
	ping("ACTION=" +  arg);
}

//------------------------------
//
//------------------------------
function change_overlay(arg) {
	if (IDS.overlay == arg)
		return;
	IDS.overlay = arg;
	setup_annotations(arg);
	ping("OVERLAY=" +  arg);
}

//------------------------------
//
//------------------------------
function drmenu_item_click(sig, handler, value) {
<% if (m_browser.type == "NN") { %>
	var menu_list = document.layers['DrMenuList-' + sig];
	menu_list.visibility = 'hidden';
<% } else { %>
	var menu_list = document.<%=m_cfn.getElementById%>('DrMenuList-' + sig);
	menu_list.style.display = 'none';
<% } %>
	if (handler != null)
		handler(value);
}

//------------------------------
//
//------------------------------
function drmenu_init(sig) {
<% if (m_browser.type == "NN") { %>
	var anchor = document.layers['DrMenuAnchor-' + sig];
	var menu_button = document.layers['DrMenuButton-' + sig];
	var menu_list = document.layers['DrMenuList-' + sig];
	menu_button.moveTo(anchor.pageX, anchor.pageY);
	menu_button.resizeTo(anchor.clip.width, anchor.clip.height);
	menu_list.moveTo(anchor.pageX, anchor.pageY + <%=(kMenuBarHeight - 6)%>);
	menu_button.onMouseOver = new Function("event", "drmenu_event(event, true, '" + sig + "', true); return false;");
	menu_button.onMouseOut = new Function("event", "drmenu_event(event, false, '" + sig + "', true); return false;");
	menu_list.onMouseOver = new Function("event", "drmenu_event(event, true, '" + sig + "', false); return false;");
	menu_list.onMouseOut = new Function("event", "drmenu_event(event, false, '" + sig + "', false); return false;"); 
<% } else { %>
	var left = 0;
	var top = 0;
	var menu_button = document.<%=m_cfn.getElementById%>('DrMenuButton-' + sig);
	var div = menu_button;
	while (div.tagName != "BODY") {
		left += div.offsetLeft;
		top += div.offsetTop;
		div = div.offsetParent;
	}
	var menu_list = document.<%=m_cfn.getElementById%>('DrMenuList-' + sig);
	menu_list.style.<%=m_cfn.posLeft%> = left + 1;
	menu_list.style.<%=m_cfn.posTop%> = top + <%=kMenuBarHeight%>;
	menu_list.style.display = 'none';
<% } %>
}

//------------------------------
//
//------------------------------
function drmenu_event(event, onOver, sig, onButton) {
<% if (m_browser.type == "NN") { %>
	var menu_list = document.layers['DrMenuList-' + sig];
	if (onOver)
		menu_list.visibility = 'show';
	else
		menu_list.visibility = 'hidden';
<% } else if (m_browser.type == "IE") { %>
	event.cancelBubble = true;
	event.returnValue = false;
	var menu_list = document.all('DrMenuList-' + sig);
	if (onOver) {
		if (menu_list.style.display != 'block')
			menu_list.style.display = 'block';
	} else {
		if (menu_list.style.display != 'none') {
			menu_list.style.display = 'none';
		}
	}
<% } else { %>
<%  if (m_browser.type == "GE" && m_browser.version < 1.1) { %>
	onOver = event.clientX >= event.currentTarget.offsetLeft && event.clientX <= event.currentTarget.offsetLeft + event.currentTarget.offsetWidth
	      && event.clientY >= event.currentTarget.offsetTop && event.clientY <= event.currentTarget.offsetTop + event.currentTarget.offsetHeight;
<%  } %>
	var menu_list = document.getElementById('DrMenuList-' + sig);
	if (onOver) {
		if (menu_list.style.display != 'block')
			menu_list.style.display = 'block';
	} else {
		if (menu_list.style.display != 'none') {
			menu_list.style.display = 'none';
		}
	}
<% } %>
}

//------------------------------
//
//------------------------------
function SetupSeriesDetail() {
<% if (m_browser.type == "NN") { %>
	var lay = document.layers['SeriesDetail'];
	var alay = lay.document.layers[0];
	lay.moveTo(0, <%=QSV.window_height%> - alay.pageY - 16);
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>('SeriesDetail');
	div.style.<%=m_cfn.posLeft%> = 1;
	div.style.<%=m_cfn.posTop%> = <%=QSV.window_height%> - div.offsetHeight;
	div.style.display = 'none';
<% } %>
}

//------------------------------
//
//------------------------------
function show_series_detail() {
<% if (m_browser.type == "NN") { %>
	var lay = document.layers['SeriesDetail'];
	if (lay.visibility != 'show')
		lay.visibility = 'show';
	else
		lay.visibility = 'hidden';
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>('SeriesDetail');
	if (div.style.display == 'none')
		div.style.display = 'block';
	else
		div.style.display = 'none';
<% } %>
}

//----------------------------------------------------------------------------------------
</SCRIPT>
<SCRIPT LANGUAGE="JavaScript1.2">
//----------------------------------------------------------------------------------------
// Viewer dependant code
//----------------------------------------------------------------------------------------

//------------------------------
//
//------------------------------
var image_orientation_table = "<%=ImageObject.image_orientation_table%>";

<% if (m_browser.type == "NN") { %>
//------------------------------
//
//------------------------------
IR.prototype.get_annotation = function(flag) {
	if (flag == 'N') {
		return '<SPAN CLASS="ANNTEXT">' + this.number + '</SPAN>';
	} else if (flag == 'D') {

		var TL = 'No: ' + this.number + '<BR>';
		if (this.xd != 0 && this.yd != 0 && this.xd != 5 && this.yd != 5 && this.xd != 6 && this.yd != 6)
			TL += 'Ax: ' + (this.z < 0 ? 'F' : (this.z > 0 ? 'H' : '')) + (Math.floor(Math.abs(this.z) * 10 + 0.5) / 10);
		else if (this.xd != 0 && this.yd != 0 && this.xd != 3 && this.yd != 3 && this.xd != 4 && this.yd != 4)
			TL += 'Cr: ' + (this.y < 0 ? 'A' : (this.y > 0 ? 'P' : '')) + (Math.floor(Math.abs(this.y) * 10 + 0.5) / 10);
		else if (this.xd != 0 && this.yd != 0 && this.xd != 1 && this.yd != 1 && this.xd != 2 && this.yd != 2)
			TL += 'Sg: ' + (this.x < 0 ? 'L' : (this.x > 0 ? 'R' : '')) + (Math.floor(Math.abs(this.x) * 10 + 0.5) / 10);
		var fovx = 0, fovy = 0;
		if (IDS.zoom == 1.0) {
			fovx = Math.floor(this.cols * this.xs + 0.5);
			fovy = Math.floor(this.rows * this.ys + 0.5);
		} else {
			fovx = Math.floor(this.cols * this.xs / IDS.zoom + 0.5);
			fovy = Math.floor(this.rows * this.ys / IDS.zoom + 0.5);
		}
		if (fovx != 0 && fovy != 0)
			TL += '<BR>FOV: ' + fovx + 'x' + fovy;

		var TR = "";
		if (this.time != 0)
			TR = 'Tm: ' + prettyTime(this.time);

		var BL = 'L: ' + this.wc + '<BR>W: ' + this.ww;

		var TC = image_orientation_table.charAt(this.yd * 2);
		var BC = image_orientation_table.charAt(this.yd * 2 + 1);

		var ML = image_orientation_table.charAt(this.xd * 2);
		var MR = image_orientation_table.charAt(this.xd * 2 + 1);

		return '<TABLE HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0" ROWS="3" COLS="3" WIDTH="100%" HEIGHT="100%">'
		     + '<TR VALIGN="TOP" HEIGHT="40%">'
		     + '<TD ALIGN="LEFT" WIDTH="40%" CLASS="ANNTEXT">' + TL + '</TD>'
		     + '<TD ALIGN="CENTER" WIDTH="20%" CLASS="ANNTEXT">' + TC + '</TD>'
		     + '<TD ALIGN="RIGHT" WIDTH="40%" CLASS="ANNTEXT">' + TR + '</TD>'
		     + '</TR>'
		     + '<TR VALIGN="MIDDLE" HEIGHT="20%">'
		     + '<TD ALIGN="LEFT" CLASS="ANNTEXT">' + ML + '</TD>'
		     + '<TD></TD>'
		     + '<TD ALIGN="RIGHT" CLASS="ANNTEXT">' + MR + '</TD>'
		     + '</TR>'
		     + '<TR VALIGN="BOTTOM" HEIGHT="40%">'
		     + '<TD ALIGN="LEFT" CLASS="ANNTEXT">' + BL + '</TD>'
		     + '<TD ALIGN="CENTER" WIDTH="20%" CLASS="ANNTEXT">' + BC + '</TD>'
		     + '<TD></TD>'
		     + '</TR>'
		     + '</TABLE>';
	} else {
		return '';
	}
}
<% } else { %>
<%  if (m_browser.os == "M" && m_browser.type == "IE") { %>
//------------------------------
//
//------------------------------
IR.prototype.make_measure_table = function(key, anntext) {

	//------------------------------
	//
	//------------------------------
	function select_measure_length(pixel_spacing, limit) {
		var real_len_list = new Array(1.0, 10.0, 100.0);
		var disp_len_list = new Array(0.0,  0.0,   0.0);
		for (var i = 0; i < real_len_list.length; i++) {
			var rlen = real_len_list[i];
			var dlen = rlen / pixel_spacing;
			if (dlen < 16)
				continue;
			if (dlen > limit)
				continue;			
			disp_len_list[i] = dlen;
		}
		for (var i = disp_len_list.length - 1; i >= 0; i--) {
			var dlen = disp_len_list[i];
			if (dlen != 0.0)
				return dlen;
		}
		return 0;
	}

	var scale = IDS.zoom * <%=LayoutTable.layout.scale%>;
	var ps, limit;
	switch (key) {
	case 'BC':
		ps = this.xs / scale;
		limit = <%=LayoutTable.layout.width * 2 / 3%>;
		break;
	case 'MR':
		ps = this.ys / scale;
		limit = <%=LayoutTable.layout.height * 2 / 3%>;
		break;
	}

	var length = select_measure_length(ps, limit);
	if (length == 0)
		return anntext;

	length = Math.floor(length + 0.5);

	var html;
	switch (key) {
	case 'BC':
		html = '<table style="position:absolute;height:16;top:<%=LayoutTable.layout.height - 16%>;left:' + Math.floor((<%=LayoutTable.layout.width%> - length) / 2) + ';width:' + length + ';" cellpadding="0" cellspacing="0">';
		html += '<tr><td class="ANNTEXT" align="center" valign="top" style="border-top:1px solid #FFAA00;">';
		html += anntext;
		html += '</td></tr>';
		break;

	case 'MR':
		html = '<table style="position:absolute;height:' + length + ';top:' + Math.floor((<%=LayoutTable.layout.height%> - length) / 2) + ';left:<%=LayoutTable.layout.width - 16%>;" cellpadding="0" cellspacing="0">';
		html += '<tr><td class="ANNTEXT" align="right" valign="middle" style="border-left:1px solid #FFAA00;">';
		html += anntext;
		html += '</td></tr>';
		break;
	}

	return html + '</table>';

}
<%  } else { %>
//------------------------------
//
//------------------------------
IR.prototype.make_measure_table = function(key, anntext) {

	//------------------------------
	//
	//------------------------------
	function select_measure_unit(pixel_spacing, limit) {
		var real_len_list = new Array(1.0, 10.0, 100.0);
		var disp_len_list = new Array(0.0,  0.0,   0.0);
		for (var i = 0; i < real_len_list.length; i++) {
			var rlen = real_len_list[i];
			var dlen = rlen / pixel_spacing;
			if (dlen < 16)
				continue;
			if (dlen > limit)
				continue;			
			disp_len_list[i] = dlen;
		}
		for (var i = 0; i < disp_len_list.length; i++) {
			var dlen = disp_len_list[i];
			if (dlen != 0.0)
				return dlen;
		}
		return 0;
	}

	var scale = IDS.zoom * <%=LayoutTable.layout.scale%>;
	var ps, limit;
	switch (key) {
	case 'BC':
		ps = this.xs / scale;
		limit = <%=LayoutTable.layout.width * 2 / 3%>;
		break;
	case 'MR':
		ps = this.ys / scale;
		limit = <%=LayoutTable.layout.height * 2 / 3%>;
		break;
	}

	var unit = select_measure_unit(ps, limit);
	if (unit == 0)
		return anntext;

	var count = Math.floor(limit / unit);
	if (count > 10)
		count = 10;

	var size = Math.ceil(unit * count);

	var html;
	switch (key) {
	case 'BC':
		html = '<table style="position:absolute;height:24;top:<%=LayoutTable.layout.height - 24%>;left:' + Math.floor((<%=LayoutTable.layout.width%> - size) / 2) + ';width:' + size + ';border-collapse:collapse;" cellpadding="0" cellspacing="0" cols="' + count + '" rows="2">';
		html += '<tr style="height:5;">';
		var last_x = 0;
		for (var i = 0; i < count; i++) {
			var x = Math.floor((i + 1) * unit + 0.5);
			var width = x - last_x - 1;
			last_x = x;
			html += '<td style="width:' + width + ';';
			if (i == 0)
				html += 'border-left:1px solid #FFAA00;'
			html += 'border-right:1px solid #FFAA00;"></td>';
		}
		html += '</tr>';
		html += '<tr><td class="ANNTEXT" colspan="' + count + '" align="center" valign="top" style="border-top:1px solid #FFAA00;">';
		html += anntext;
		html += '</td></tr>';
		break;

	case 'MR':
		html = '<table style="position:absolute;height:' + size + ';top:' + Math.floor((<%=LayoutTable.layout.height%> - size) / 2) + ';left:<%=LayoutTable.layout.width - 16%>;border-collapse:collapse;" cellpadding="0" cellspacing="0" rows="' + count + '" cols="2">';
		var last_y = 0;
		for (var i = 0; i < count; i++) {
			var y = Math.floor((i + 1) * unit + 0.5);
			var height = y - last_y;
			last_y = y;
			if (i == count - 1)
				height++;
			html += '<tr style="height:' + height + ';">';
			html += '<td style="width:5;border-top:1px solid #FFAA00;';
			if (i == count - 1)
				html += 'border-bottom:1px solid #FFAA00;';
			html += '"></td>';
			if (i == 0) {
				html += '<td class="ANNTEXT" rowspan="' + count + '" align="left" valign="middle" style="border-left:1px solid #FFAA00;">';
				html += anntext;
				html += '</td>';
			}
			html += '</tr>';
		}
		break;
	}

	return html + '</table>';

}
<%  } %>
//------------------------------
//
//------------------------------
IR.prototype.put_annotation = function(flag, index) {
	var html = "";
	if (flag == 'N') {
		var TL = '<DIV STYLE="position:absolute;top:0;left:0;" CLASS="ANNTEXT">';
		TL += this.number;
		TL += '<DIV>';
		html = TL;
	} else if (flag == 'D') {

		var TL = '<DIV STYLE="position:absolute;top:0;left:0;" CLASS="ANNTEXT">';
		TL += 'No: ' + this.number + '<BR>';
		if (this.xd != 0 && this.yd != 0 && this.xd != 5 && this.yd != 5 && this.xd != 6 && this.yd != 6)
			TL += 'Ax: ' + (this.z < 0 ? 'F' : (this.z > 0 ? 'H' : '')) + (Math.floor(Math.abs(this.z) * 10 + 0.5) / 10);
		else if (this.xd != 0 && this.yd != 0 && this.xd != 3 && this.yd != 3 && this.xd != 4 && this.yd != 4)
			TL += 'Cr: ' + (this.y < 0 ? 'A' : (this.y > 0 ? 'P' : '')) + (Math.floor(Math.abs(this.y) * 10 + 0.5) / 10);
		else if (this.xd != 0 && this.yd != 0 && this.xd != 1 && this.yd != 1 && this.xd != 2 && this.yd != 2)
			TL += 'Sg: ' + (this.x < 0 ? 'L' : (this.x > 0 ? 'R' : '')) + (Math.floor(Math.abs(this.x) * 10 + 0.5) / 10);
		var fovx = 0, fovy = 0;
		if (IDS.zoom == 1.0) {
			fovx = Math.floor(this.cols * this.xs + 0.5);
			fovy = Math.floor(this.rows * this.ys + 0.5);
		} else {
			fovx = Math.floor(this.cols * this.xs / IDS.zoom + 0.5);
			fovy = Math.floor(this.rows * this.ys / IDS.zoom + 0.5);
		}
		if (fovx != 0 && fovy != 0)
			TL += '<BR>FOV: ' + fovx + 'x' + fovy;
		TL += '</DIV>';

		var TC = '<DIV style="position:absolute;top:0;left:<%=Math.Floor(Convert.ToDouble(LayoutTable.layout.width / 2 - 8))%>;width:16;text-align:center;" CLASS="ANNTEXT">';
		TC += image_orientation_table.charAt(this.yd * 2);
		TC += '</DIV>';

		var TR = '';
		if (this.time != 0) {
			TR = '<TABLE style="position:absolute;top:0;left:<%=Math.Floor(Convert.ToDouble(LayoutTable.layout.width / 2 + 8))%>;width:<%=LayoutTable.layout.width / 2 - 8%>;"><tr><td valign="top" align="right" CLASS="ANNTEXT">';
			TR += 'Tm: ' + prettyTime(this.time);
			TR += '</td></tr></TABLE>';
		}

		var ML = '<TABLE style="position:absolute;top:<%=Math.Floor(Convert.ToDouble(LayoutTable.layout.height / 2 - 16))%>;height:32;left:0;"><tr><td valign="middle" align="left" CLASS="ANNTEXT">';
		ML += image_orientation_table.charAt(this.xd * 2);
		ML += '</td></tr></TABLE>';

		var BL = "";
		if (IDS.wc == 0 && IDS.ww == 0) {
			BL = '<TABLE BORDER="0" CELLSPACING="0" CELLPADDING="0" STYLE="position:absolute;top:<%=(LayoutTable.layout.height - 48)%>;left:0;height:48;"><tr><td valign="bottom" align="left" CLASS="ANNTEXT">';
			BL += 'L: ' + this.wc + '<BR>W: ' + this.ww;
			BL += '</td</tr></TABLE>\n';
		}

		var MR = this.make_measure_table('MR', image_orientation_table.charAt(this.xd * 2 + 1));

		var BC = this.make_measure_table('BC', image_orientation_table.charAt(this.yd * 2 + 1));

		html = TL + TC + TR + ML + MR + BC + BL;
	}
	var div = document.<%=m_cfn.getElementById%>('ANN-' + index);
	div.innerHTML = html;
}
<% } %>

//------------------
// Sort Image List
//------------------
function SortIL(orderKey) {

	var ok = orderKey.split(',');
	if (ok.length != 2) {
		IL.sort(compImageNumberA);
		return;
	}

	switch (ok[0]) {
	case 'N':
		if (ok[1] == 'A')
			IL.sort(compImageNumberA);
		else
			IL.sort(compImageNumberD);
		return;
	case 'T':
		if (ok[1] == 'A')
			IL.sort(compImageTimeA);
		else
			IL.sort(compImageTimeD);
		return;
	case 'Z':
		if (ok[1] == 'A')
			IL.sort(compImagePositionZA);
		else
			IL.sort(compImagePositionZD);
		return;
	case 'Y':
		if (ok[1] == 'A')
			IL.sort(compImagePositionYA);
		else
			IL.sort(compImagePositionYD);
		return;
	case 'X':
		if (ok[1] == 'A')
			IL.sort(compImagePositionXA);
		else
			IL.sort(compImagePositionXD);
		return;
	default:
		IL.sort(compImageNumberA);
		return;
	}
}

//----------------------------
// Image Comparison Functions
//---------------------------
//----------------
function compImageNumberA(a, b) {
	return a.number - b.number;
}
//----------------
function compImageNumberD(b, a) {
	return a.number - b.number;
}

//----------------
function compImageTimeA(a, b) {
	var diff = a.date - b.date;
	if (diff != 0)
		return diff;
	diff = a.time - b.time;
	if (diff != 0)
		return diff;
	return compImageNumberA(a, b);
}
//----------------
function compImageTimeD(b, a) {
	var diff = a.date - b.date;
	if (diff != 0)
		return diff;
	diff = a.time - b.time;
	if (diff != 0)
		return diff;
	return compImageNumberD(a, b);
}

//----------------
function compImagePositionZA(a, b) {
	var diff = a.z - b.z;
	if (diff != 0)
		return diff;
	return compImageNumberA(a, b);
}
//----------------
function compImagePositionZD(b, a) {
	var diff = a.z - b.z;
	if (diff != 0)
		return diff;
	return compImageNumberD(a, b);
}
//----------------
function compImagePositionYA(a, b) {
	var diff = a.y - b.y;
	if (diff != 0)
		return diff;
	return compImageNumberA(a, b);
}
//----------------
function compImagePositionYD(b, a) {
	var diff = a.y - b.y;
	if (diff != 0)
		return diff;
	return compImageNumberD(a, b);
}
//----------------
function compImagePositionXA(a, b) {
	var diff = a.x - b.x;
	if (diff != 0)
		return diff;
	return compImageNumberA(a, b);
}
//----------------
function compImagePositionXD(b, a) {
	var diff = a.x - b.x;
	if (diff != 0)
		return diff;
	return compImageNumberD(a, b);
}

//------------------------------
//
//------------------------------
function findFirstImageIndex() {
<% if (LayoutTable.noscroll) { %>
	return 0;
<% } else if (QSV.first_index >= 0) { %>
	return <%=QSV.first_index%>;
<% } else { %>
	return 0;
<% } %>
}

//------------------------------
// ImageDisplaySetting
//------------------------------
function ImageDisplaySetting() {

	// Zoom
	this.zoom = <%=QSV.zoom%>;
	this.zx = <%=(QSV.zx < 0 ? get_data_US(null, DOM, 0x00280011, 0) / 2 : QSV.zx)%>;
	this.zy = <%=(QSV.zy < 0 ? get_data_US(null, DOM, 0x00280010, 0) / 2 : QSV.zy)%>;

	// VOI
	this.wc = <%=VOITable.wc%>;
	this.ww = <%=VOITable.ww%>;

	// Display Range
	this.first_index = findFirstImageIndex();

	// mode
	this.overlay = '<%=QSV.overlay%>';
	this.action = '<%=QSV.action%>';

	this.fit = '<%=QSV.fit%>';
	this.order = '<%=QSV.order%>';

	this.layout_rows = <%=LayoutTable.layout.rows%>;
	this.layout_cols = <%=LayoutTable.layout.cols%>;
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.query_string = function() {
	return '&VOI=' + escape('' + this.wc + ',' + this.ww)
	     + '&FI=' + this.first_index
	     + (this.zoom > 1 ? '&ZOOM=' + this.zoom + '&ZX=' + this.zx + '&ZY=' + this.zy : '')
	     + '&FIT=' + escape(this.fit)
	     + '&ORDER=' + escape(IDS.order)
	     + '&LAYOUT=' + escape(IDS.layout_rows + ',' + IDS.layout_cols)
	     + '&ACTION=' + escape(IDS.action)
	     + '&OVERLAY=' + escape(IDS.overlay);
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.image_src = function(index, nocache) {
	index += this.first_index;
	if (index >= IL.length)
		return '/DIOWave/bbox.gif';
	return IL[index].uri()
		+ '?WC=' + this.wc
		+ '&WW=' + this.ww
		+ '&HEIGHT=<%=LayoutTable.layout.height%>'
		+ '&WIDTH=<%=LayoutTable.layout.width%>'
		+ (this.zoom != 1.0 ? '&SCALE=' + (this.zoom * <%=LayoutTable.layout.scale%>) + '&ZX=' + this.zx + '&ZY=' + this.zy : '')
		+ (nocache ? '&CACHE=2' : '');
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.icon_src = function(index) {
	return IL[index].uri()
		+ '?WIDTH=<%=kStripWidth%>'
		+ '&HEIGHT=<%=kStripWidth%>'
		<%=(update_icon ? " + '&WC=' + this.wc + '&WW=' + this.ww" : "")%>;
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.set_first_index = function(index) {
	if (index < 0)
		index = 0;
	else if (index > <%=(NumImages - LayoutTable.layout.num_images)%>)
		index = <%=(NumImages - LayoutTable.layout.num_images)%>;

	var r = index != this.first_index;
	if (r)
		this.first_index = index;

	return r;
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.set_zoom_center = function(x, y, anchor_x, anchor_y, anchor_X, anchor_Y) {
<%/*
	X2: ړ̃}EX̉ɂȂ|Cg̃IWi摜ł̍W
	x2: ړ̃}EX̉ɂȂ|Cg̕\̍W
	C2: ړ̕\̒SɂȂ|Cg̃IWi摜̂ł̍W
	c2: ړ̕\̒SW

	X1: ړÕ}EX̉ɂ|Cg̃IWi摜̍W
	x1: ړÕ}EX̉ɂ|Cg̕\̍W
	C1: ړO̕\̒S̃|Cg̃IWi摜ł̍W
	c1: ړO̕\̒SW

	S: XP[

	X2 = X1 = X
	c2 = c1 = c

	(X2 - C2) * S = x2 - c2
	(X2 - C1) * S = x1 - c2

	(X - C2) * S = x2 - c
	(X - C1) * S = x1 - c

	C2 = (x1 - x2)/S + C1

*/%>
	var S = <%=LayoutTable.layout.scale%> * this.zoom;

	this.zx = Math.floor((anchor_x - x)/S + anchor_X);
	this.zy = Math.floor((anchor_y - y)/S + anchor_Y);

	this.adjust_zoom_center();
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.set_zoom_center2 = function(x, y, zoom) {
<%/*
	X2: Y[̃}EX̉ɂȂ|Cg̃IWi摜ł̍W
	x2: Y[̃}EX̉ɂȂ|Cg̕\̍W
	C2: Y[̕\̒SɂȂ|Cg̃IWi摜̂ł̍W
	c2: Y[̕\̒SW
	S2: Y[̃XP[

	X1: Y[Õ}EX̉ɂ|Cg̃IWi摜̍W
	x1: Y[Õ}EX̉ɂ|Cg̕\̍W
	C1: Y[O̕\̒S̃|Cg̃IWi摜ł̍W
	c1: Y[O̕\̒SW
	S1: Y[ÕXP[


	(X1 - C1) * S1 = (x1 - c1)
	(X2 - C2) * S2 = (x2 - c2)

	c1 = c2 = c
	x1 = x2 = x
	X1 = X2 = X

	(X - C1) * S1 = x - c
	(X - C2) * S2 = x - c

	X = (x - c) / S1 + C1
	  = (x - c) / S2 + C2

	C2 = C1 + (x - c)/S1 - (x - c)/S2
*/%>
	var cx = <%=LayoutTable.layout.width%> / 2;
	var cy = <%=LayoutTable.layout.height%> / 2;
	var Cx = <%=get_data_US(null, DOM, 0x00280011, 0)%> / 2;
	var Cy = <%=get_data_US(null, DOM, 0x00280010, 0)%> / 2;
	var S1 = <%=LayoutTable.layout.scale%> * this.zoom;
	var S2 = <%=LayoutTable.layout.scale%> * zoom;

	this.zx = Math.floor(Cx + (x - cx)/S1 - (x - cx)/S2);
	this.zy = Math.floor(Cy + (y - cy)/S1 - (y - cy)/S2);

	this.zoom = zoom;

	this.adjust_zoom_center();
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.adjust_zoom_center = function() {
	var scale = <%=LayoutTable.layout.scale%> * this.zoom;

	var halfX = Math.floor(<%=LayoutTable.layout.width%> / scale / 2);
	var halfY = Math.floor(<%=LayoutTable.layout.height%> / scale / 2);

	if (this.zx < halfX)
		this.zx = halfX;
	else if (this.zx > <%=get_data_US(null, DOM, 0x00280011, 0)%> - halfX)
		this.zx = <%=get_data_US(null, DOM, 0x00280011, 0)%> - halfX;

	if (this.zy < halfY)
		this.zy = halfY;
	else if (this.zy > <%=get_data_US(null, DOM, 0x00280010, 0)%> - halfY)
		this.zy = <%=get_data_US(null, DOM, 0x00280010, 0)%> - halfY;
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.set_drag_voi = function(orgWC, orgWW, x, y) {
<%/*
	sсF
	ƃ}EX𓮂ŒlςĂ܂͎̂gɂB
	܂AWC ςĂ̂ WW ܂ŕςĂ܂i邢͂̋tjgɂB
	ƂƂŁAsт݂B

	܂ASsсB͂Ƃɂ̈ړȂ΂ȂɂȂB
	ɁAIsсBXDȂAY̕sт傫Ƃi邢͂̋tj
	Isт̌`͐^Bpx͂ROx

	WC ̌vZF
	}EXړʂ 128 ̎ WW ̔ςA񎟊֐
	Y = a * x^2  --- (ww / 2) = a * (128 * 128) --- a = ww / (128 * 128 * 2)

	WW ̌vZF
	}EẌړʂ E128 ̎ WW {ɁiRgXg邭jȂ
	Y = 2^X

*/%>
	var ax = Math.abs(x);
	if (ax <= 4)
		ax = 0;
	else
		ax -= 4;
	x = x < 0 ? -ax : ax;

	var ay = Math.abs(y);
	if (ay <= 4)
		ay = 0;
	else
		ay -= 4;
	y = y < 0 ? -ay : ay;

	if (ax == 0 && ay == 0)
		return;

	var tan30 = 0.57735;
	if (ax != 0 && ay / ax < tan30) {
		this.ww = Math.floor(orgWW * Math.pow(2, x / 128));
	} else if (ay != 0 && ax / ay < tan30) {
		this.wc = orgWC + Math.floor(ay * y * orgWW / 32768);
	} else {
		this.ww = Math.floor(orgWW * Math.pow(2, x / 128));
		this.wc = orgWC + Math.floor(ay * y * orgWW / 32768);
	}
}


//------------------------------
// SliderActionObject
//------------------------------
function SliderActionObject() {
	this.md_imageX = -1;
	this.md_imageY = -1;
	this.md_pageX = -1;
	this.md_pageY = -1;

	this.box = null;
	this.indicator = null;
	this.panel_top = 0;
<% if (m_browser.type == "NN") { %>
	this.panel_left = 0;
<% } %>
	this.grip_offset = 0;
}

//------------------------------
SliderActionObject.prototype.mousedown = ActionObject_mousedown;
SliderActionObject.prototype.x = ActionObject_x;
SliderActionObject.prototype.y = ActionObject_y;
SliderActionObject.prototype.offset_x = ActionObject_offset_x;
SliderActionObject.prototype.offset_y = ActionObject_offset_y;

//------------------------------
//
//------------------------------
ImageActionObject.prototype.begin_drag = function(e) {

<% if (m_browser.type == "IE") { %>
	this.box = e.srcElement.box;
<% } else if (m_browser.type == "NN") { %>
	this.box = e.target.box;
<% } else { %>
	this.box = e.currentTarget.box;
<% } %>

	this.box.start_track_update();

	if (this.mode == 'Z') {
		var x = this.x(e);
		var y = this.y(e);
		if (IDS.zoom == 1) {
			IDS.set_zoom_center2(x, y, 2);
			this.box.track_update(true);
			setZoomText();
			reload_annotation_text();
		}
		this.anchor_x = x;
		this.anchor_y = y;
		this.anchor_X = IDS.zx;
		this.anchor_Y = IDS.zy;
	} else if (this.mode == 'V') {
		if (IDS.wc == 0 && IDS.ww == 0) {
			var img = IL[IDS.first_index + this.box.index];
			IDS.wc = img.wc;
			IDS.ww = img.ww;
			setVOIText();
		}
		this.org_wc = IDS.wc;
		this.org_ww = IDS.ww;
	} else if (this.mode == 'P') {
<% if (!LayoutTable.noscroll) { %>
		this.org_first_index = IDS.first_index;	
<% } %>
	}
}

//------------------------------
//
//------------------------------
ImageActionObject.prototype.do_drag = function(e) {
	if (this.mode == 'Z') {
		var x = IDS.zx;
		var y = IDS.zy;
		IDS.set_zoom_center(this.x(e), this.y(e), this.anchor_x, this.anchor_y, this.anchor_X, this.anchor_Y);
		if (IDS.zx != x || IDS.zy != y)
			this.box.track_update(true);
	} else if (this.mode == 'V') {
		var wc = IDS.wc;
		var ww = IDS.ww;
		IDS.set_drag_voi(this.org_wc, this.org_ww, this.offset_x(e), this.offset_y(e));
		if (IDS.wc != wc || IDS.ww != ww) {
			this.box.track_update(true);
			setVOIText();
		}
	} else if (this.mode == 'P') {
<% if (!LayoutTable.noscroll) { %>
		var index = this.org_first_index + Math.floor(this.offset_y(e) / 16);
		if (IDS.set_first_index(index)) {
			this.box.track_update(false);
			this.box.set_annotation();
			SliderAction.set_indicator();
		}
<% } %>
	}
}

//------------------------------
//
//------------------------------
ImageActionObject.prototype.end_drag = function(e) {
	if (this.mode == 'Z') {
		IDS.set_zoom_center(this.x(e), this.y(e), this.anchor_x, this.anchor_y, this.anchor_X, this.anchor_Y);
		reload_imgbox(ImageBoxTable);
	} else if (this.mode == 'V') {
		IDS.set_drag_voi(this.org_wc, this.org_ww, this.offset_x(e), this.offset_y(e));
		reload_imgbox(ImageBoxTable);
		reload_annotation_text();
		<%=(update_icon ? "reload_imgbox(IconBoxTable);" : "")%>
		setVOIText();
	} else if (this.mode == 'P') {
<% if (!LayoutTable.noscroll) { %>
		var index = this.org_first_index + Math.floor(this.offset_y(e) / 16);
		if (IDS.set_first_index(index))
			this.set_indicator();
		reload_imgbox(ImageBoxTable);
		reload_annotation_text();
<% } %>
	}

	this.box.end_track_update();
}

//------------------------------
//
//------------------------------
ImageActionObject.prototype.dblclick = function(e) {

	if (IDS.layout_rows == 1 && IDS.layout_cols == 1)
		return;

<% if (m_browser.type == "IE") { %>
	this.box = e.srcElement.box;
<% } else if (m_browser.type == "NN") { %>
	this.box = e.target.box;
<% } else { %>
	this.box = e.currentTarget.box;
<% } %>

	IDS.first_index += this.box.index;

	IDS.layout_rows = 1;
	IDS.layout_cols = 1;

	Reload();
}

//------------------------------
//
//------------------------------
SliderActionObject.prototype.calc_index = function(y) {
	return Math.floor((y - this.grip_offset) / <%=SliderPanel.ind_step%>);
}

//------------------------------
//
//------------------------------
SliderActionObject.prototype.begin_drag = function(e) {
<% if (LayoutTable.noscroll) { %>
	return;
<% } %>
	for (var i in ImageBoxTable)
		ImageBoxTable[i].start_track_update();

	var y = this.y(e);

	var slider_top = Math.floor(<%=SliderPanel.ind_step%> * IDS.first_index);
	var slider_bottom = slider_top + <%=SliderPanel.ind_height%>;
	if (y >= slider_top && y < slider_bottom) {
		this.grip_offset = y - slider_top;
	} else {
		this.grip_offset = <%=(SliderPanel.ind_height / 2)%>;
		var index = this.calc_index(y);
		if (IDS.set_first_index(index)) {
			for (var i in ImageBoxTable) {
				var box = ImageBoxTable[i];
				box.track_update(false);
				box.set_annotation();
			}
			this.set_indicator();
		}
	}
}

//------------------------------
//
//------------------------------
SliderActionObject.prototype.do_drag = function(e) {
<% if (LayoutTable.noscroll) { %>
	return;
<% } %>
	var index = this.calc_index(this.y(e));
	if (IDS.set_first_index(index)) {
		for (var i in ImageBoxTable) {
			var box = ImageBoxTable[i];
			box.track_update(false);
			box.set_annotation();
		}
		this.set_indicator();
	}
}

//------------------------------
//
//------------------------------
SliderActionObject.prototype.end_drag = function(e) {
<% if (LayoutTable.noscroll) { %>
	return;
<% } %>
	if (this.offset_x(e) == 0 && this.offset_y(e) == 0) {
		for (var i in ImageBoxTable) {
			ImageBoxTable[i].end_track_update();
		}
	} else {
		var index = this.calc_index(this.y(e));
		if (IDS.set_first_index(index)) {
			for (var i in ImageBoxTable) {
				var box = ImageBoxTable[i];
				box.track_update(false);
				box.set_annotation();
				box.end_track_update();
			}
			this.set_indicator();
		}
	}
}

//------------------------------
//
//------------------------------
SliderActionObject.prototype.set_indicator = function() {
<% if (NumImages > 1) { %>
<%  if (m_browser.type == "IE") { %>
	this.indicator.style.pixelTop = this.panel_top + Math.floor(<%=SliderPanel.ind_step%> * IDS.first_index);
<%  } else if (m_browser.type == "NN") { %>
	this.indicator.moveTo(this.panel_left, this.panel_top + Math.floor(<%=SliderPanel.ind_step%> * IDS.first_index));
<%  } else { %>
	this.indicator.style.top = this.panel_top + Math.floor(<%=SliderPanel.ind_step%> * IDS.first_index);
<%  } %>
<% } %>
}

//------------------------------
// IconBox
//------------------------------
function IconBox(img, index) {
	this.img = img;
	this.index = index;
}
//------------------------------
//
//------------------------------
IconBox.prototype.reload = function() {
	this.img.src = IDS.icon_src(this.index);
}

//------------------------------
//
//------------------------------
function reload_imgbox(table) {
	for (var i in table) {
		var box = table[i];
		box.reload();
	}
}

//------------------------------
//
//------------------------------
function setup_imgboxes() {
	for (var i = 0; i < document.images.length; i++) {
		var img = document.images[i];
		var name = img.name;
		if (name.indexOf('IMG-') == 0) {
			var index = name.substring(4);
			var box = new ImageBox(img, parseInt(index));
			ImageBoxTable[index] = box;
			img.box = box;
<% if (m_browser.type == "IE") { %>
<%  if (m_browser.version >= 5.5) { %>
			document.all('ACTTD-' + index).box = box;
<%  } else { %>
			document.all('ACT-' + index).box = box;
<%  } %>
<% } else if (m_browser.type == "NN") { %>
			var layer = document.layers['ANC-' + index];
			document.layers['ANN-' + index].moveTo(layer.pageX, layer.pageY);
			document.layers['ACT-' + index].moveTo(layer.pageX, layer.pageY);
			document.layers['ACT-' + index].document.box = box;
<% } else { %>
			document.getElementById('ACT-' + index).box = box;
<% } %>
		} else if (name.indexOf('ICN-') == 0) {
			var index = name.substring(4);
			var box = new IconBox(img, parseInt(index));
			IconBoxTable[IconBoxTable.length] = box;
			img.box = box;
		}
	}
}


//------------------------------
//
//------------------------------
function setup_sliderpanel() {
<% if (NumImages > 1) { %>
<%  if (m_browser.type == "NN") { %>
	var anchorLayer = document.layers['SLIDER-ANC'];
	var layer = document.layers['SLIDER-ACT'];
	layer.document.onMouseDown = onSliderMouseDown;
	layer.document.captureEvents(Event.MOUSEDOWN);
	layer = document.layers['SLIDER-IND'];
	layer.visibility = 'show';
	SliderAction.indicator = layer;
	SliderAction.panel_top = anchorLayer.pageY;
	SliderAction.panel_left = anchorLayer.pageX
<%  } else { %>
	var div = document.<%=m_cfn.getElementById%>('SLIDER-ACT');
	div.onmousedown = onSliderMouseDown;
	div.style.visibility = 'visible';
	div = document.<%=m_cfn.getElementById%>('SLIDER-IND');
	div.style.visibility = 'visible';
	SliderAction.indicator = div;
	SliderAction.panel_top = div.offsetTop;
<%  } %>
<% } %>
}

//------------------------------
//
//------------------------------
function set_annotation1(flag, index) {
<% if (m_browser.type == "NN") { %>
	var layer = document.layers['ANN-' + index];
	if (flag == '.') {
		layer.visibility = 'hide';
	} else {
		var ilindex = IDS.first_index + index;
		if (ilindex < IL.length) {
			var img = IL[ilindex];
			var laydoc = layer.document;
			laydoc.open('text/html', 'replace');
			laydoc.write(img.get_annotation(flag));
			laydoc.close();
			layer.visibility = 'show';
		}
	}
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>('ANN-' + index);
	if (flag == '.') {
		div.style.visibility = 'hidden';
	} else {
		var ilindex = IDS.first_index + index;
		if (ilindex < IL.length) {
			var img = IL[ilindex];
			img.put_annotation(flag, index);
			div.style.visibility = 'visible';
		}
	}
<% } %>
}

//------------------------------
//
//------------------------------
function setup_annotations(flag) {
	for (var i = 0; i < <%=LayoutTable.layout.num_images%>; i++)
		set_annotation1(flag, i);
}

//------------------------------
//
//------------------------------
function reload_annotation_text() {
	setup_annotations(IDS.overlay);
}

//------------------------------
//
//------------------------------
function setup_action(flag) {
	for (var i = 0; i < <%=LayoutTable.layout.num_images%>; i++) {
<% if (m_browser.type == "NN") { %>
		var layer = document.layers['ACT-' + i];
		if (flag == '.') {
			layer.visibility = 'hide';
			layer.document.onMouseDown = null;
			layer.document.releaseEvents(Event.MOUSEDOWN);
		} else {
			layer.visibility = 'show';
			layer.document.onMouseDown = onImageMouseDown;
 			layer.document.captureEvents(Event.MOUSEDOWN);
		}
<% } else { %>
		var div = document.<%=m_cfn.getElementById%>('ACT-' + i);
		if (flag == '.') {
			div.style.visibility = 'hidden';
			div.onmousedown = null;
		} else {
			div.style.visibility = 'visible';
			div.onmousedown = onImageMouseDown;
			div.ondblclick = onImageDblClick;
		}
<% } %>
	}
	ImageAction.mode = flag;
}

//------------------------------
//
//------------------------------
function Reload() {
	location.replace('spatial-series-viewer.aspx'
	               + '?VOLUME=<%=QSV.volume%>'
	               + '&PATH=<%=QSV.path%>'
	               + '&SERIES=<%=QSV.series_uid%>'
	               + '&WW=' + <%=window_width()%>
	               + '&WH=' + <%=window_height()%>
	               + IDS.query_string());
}

//------------------------------
//
//------------------------------
function Jump(flag) {
	var index = IDS.first_index;
	switch (flag) {
	case -1:
		index -= <%=LayoutTable.layout.num_images%>;
		break;
	case 1:
		index += <%=LayoutTable.layout.num_images%>;
		break;
	}

	if (IDS.set_first_index(index)) {
		reload_imgbox(ImageBoxTable);
		reload_annotation_text();		
		SliderAction.set_indicator();
	}
}

//------------------------------
//
//------------------------------
function setActionText() {
	var str;
	switch (IDS.action) {
	case 'Z':
		if (IDS.zoom == 1)
			str = 'Zoom';
		else
			str = 'Pan';
		break;
	case 'V':
		str = 'W/L';
		break;
	case 'P':
		str = 'Page';
		break;
	default:
		str = '';
		break;
	}
	SetVarText('ACTION', str);
}
//------------------------------
//
//------------------------------
function setZoomText() {

	//--------------------------
	//
	//--------------------------
	function round_ceil(v, f) {
		return (Math.ceil(v * f) / f).toString();
	}
	SetVarText('ZOOM', 'X ' + IDS.zoom + ' (' + (Math.ceil(IDS.zoom * <%=LayoutTable.layout.scale%> * 1000) / 10) + '%)');
	setActionText();
}
//------------------------------
//
//------------------------------
function setOrderText() {
	var str = '';
	var order = IDS.order.split(',');
	switch (order[0]) {
	case 'N':
		str = 'Num (' + (order[1] == 'A' ? 'N' : 'R') + ')';
		break;
	case 'T':
		str = 'Time (' + (order[1] == 'A' ? 'N' : 'R') + ')';
		break;
	case 'Z':
		str = 'Z (' + (order[1] == 'A' ? 'F-H' : 'H-F') + ')';
		break;
	case 'Y':
		str = 'Y (' + (order[1] == 'A' ? 'P-A' : 'A-P') + ')';
		break;
	case 'X':
		str = 'Y (' + (order[1] == 'A' ? 'L-R' : 'R-L') + ')';
		break;
	}

	SetVarText('ORDER', str);
}

//------------------------------
//
//------------------------------
function onSliderMouseDown(e) {
	return onActionMouseDown(e, SliderAction);
}

//------------------------------
//
//------------------------------
function onImageDblClick(e) {

<% if (m_browser.type == "IE") { %>
	e = window.event;
	if (e.shiftKey || e.altKey || e.ctlKey)
		return true;
<% } else if (m_browser.type == "NN") { %>
	if (e.which != 1 || (e.modifiers & (Event.ALT_MASK | Event.CONTROL_MASK | Event.SHIFT_MASK)) != 0)
		return true;
<% } else { %>
	if (e.altKey || e.ctrlKey || e.shiftKey || e.metaKey)
		return true;
<% } %>

	ImageAction.mousedown(e);
	ImageAction.dblclick(e);

	return false;
}

//------------------------------
//
//------------------------------
function onImageLoad(e) {
	var box = null;
<% if (m_browser.type == "IE") { %>
	e = window.event;
	box = e.srcElement.box;
<% } else if (m_browser.type == "NN") { %>
	box = e.target.box;
<% } else { %>
	box = e.currentTarget.box;
<% } %>
	if (box != null)
		box.loaded = true;
}

//------------------------------
//
//------------------------------
function onFirstLoad() {

	setup_imgboxes();

	setup_sliderpanel();

	setVOIText();
	setZoomText();
	setOrderText();

	reload_imgbox(ImageBoxTable);
	reload_imgbox(IconBoxTable);
	reload_annotation_text();
	SliderAction.set_indicator();

	setup_action(IDS.action);

	drmenu_init('L');
	drmenu_init('S');
	drmenu_init('O');
	drmenu_init('V');
	drmenu_init('Z');
	drmenu_init('A');

	SetupSeriesDetail();

<% if (m_browser.type == "NN") { %>
	pingImage = document.layers['ping'].document.images['ping'];
<% } else { %>
	pingImage = document.images['ping'];
<% } %>

	window.onload = new Function("return false;");

	return false;
}

//------------------------------
//
//------------------------------
function change_layout(arg) {
	if (arg.length == 0)
		return;

	if (arg.indexOf(',') < 0) {
		IDS.fit = arg;
		Reload();
		return;
	}

	if (IDS.fit == arg)
		return;

	var rc = arg.split(',');
	var r = parseInt(rc[0]);
	var c = parseInt(rc[1]);
	if (IDS.layout_rows == r && IDS.layout_cols == c)
		return;

	IDS.layout_rows = r;
	IDS.layout_cols = c;
	Reload();
}

//------------------------------
//
//------------------------------
function change_order(arg) {
	if (IDS.order == arg)
		return;

	IDS.order = arg;

	var anchor_offset = <%=Math.Floor((Double)(LayoutTable.layout.cols * LayoutTable.layout.cols) / 2)%>;

	var anchor = IL[IDS.first_index + anchor_offset];

	SortIL(arg);

	var index = 0;
	for (var i = 0; i < <%=NumImages%>; i++) {
		if (IL[i] == anchor) {
			index = i;
			break;
		}
	}

	IDS.set_first_index(index - anchor_offset);

	reload_imgbox(ImageBoxTable);
	reload_imgbox(IconBoxTable);
	reload_annotation_text();
	SliderAction.set_indicator();

	setOrderText();

	ping("ORDER=" +  arg);
}

//------------------------------
//
//------------------------------
function zoom_changed(arg) {
	arg = parseFloat(arg);
	if (IDS.zoom == arg)
		return;
	IDS.zoom = parseFloat(arg);
	setZoomText();
	reload_imgbox(ImageBoxTable);
	reload_annotation_text();
}

//------------------------------
//
//------------------------------
function preset_voi(arg) {
	var cw = arg.split(',');

	var wc = parseInt(cw[0]);
	var ww = parseInt(cw[1]);

	if (wc == -1 && ww == -1) {
		var str = prompt('Level / Width ̌`œ͂ĂBLevel ςꍇ Level ̒lBWidth ςꍇ / Width ̌`ł', IDS.wc + ' / ' + IDS.ww);
		if (str == null || str.length == 0)
			return;
		var ary = str.match(/\s*(-?\d+)\s*\/\s*(\d+)\s*/);
		if (ary != null) {
			wc = parseInt(ary[1]);
			ww = parseInt(ary[2]);
		} else {
			ary = str.match(/\s*\/\s*(\d+)\s*/);
			if (ary != null) {
				wc = IDS.wc;
				ww = parseInt(ary[1]);
			} else {
				ary = str.match(/\s*(-?\d+)\s*/);
				if (ary != null) {
					wc = parseInt(ary[1]);
					ww = IDS.ww;
				} else {
					alert('͂ꂽl W/L Ƃĉ߂ł܂ł');
					return;
				}
			}
		}
	}

	if (IDS.wc == wc && IDS.ww == ww)
		return;

	IDS.wc = wc;
	IDS.ww = ww;

	setVOIText(wc, ww);

	reload_imgbox(ImageBoxTable);
	reload_annotation_text();
	<%=(update_icon ? "reload_imgbox(IconBoxTable);" : "")%>
}

//------------------------------
//
//------------------------------
function ping(arg) {
	pingImage.src = "ping.aspx?" + arg;
}

//------------------------------
//
//------------------------------
<%printImageList(ImageList, ImageSpace);%>
var IDS = new ImageDisplaySetting();
var ImageBoxTable = new Array;
var IconBoxTable = new Array;
var ImageAction = new ImageActionObject();
var SliderAction = new SliderActionObject();
var CurrentAction = null;
var pingImage = null;

//----------------------------------------------------------------------------------------
</SCRIPT>
<STYLE TYPE="text/css">
/****************************************************************************************/

BODY {
	background-color:black;
	color:white;
	font-size:10pt;

	border-width: 0 0 0 0;
<% if (m_browser.type == "NN" && m_browser.os == "M") { %>
	margin-left:-6;
	margin-top:-6;
	margin-right:0;
	margin-bottom:0;
<% } else { %>
	margin: 0 0 0 0;
<% } %>
	padding: 0 0 0 0;
}

SPAN.label {
	color:#E0E0C0;
}

NOBR.STUDY_INFO {
	font-family: monospace;
	font-size: 9pt;
}

SPAN.DIRTEXT {
	font-size:9pt;
}

TD.BAR {
	background-color:#405050; /* #687686 */
	margin:0 0 0 0;
	padding:0 0 0 0;
}

TD.STRIP {
	background-color: black;
	margin:0 0 0 0;
	padding:0 0 0 0;
}

TD.CANVAS {
	background-color: #102020;
	margin:0 0 0 0;
	padding:0 0 0 0;
}

TD.ARROW {
	background-color:#405050; /* #687686 */
}

DIV.ANN {
	position:absolute;
	height:<%=LayoutTable.layout.height%>;
	width:<%=LayoutTable.layout.width%>;
	margin:0 0 0 0;
	padding:0 0 0 0;
	visibility: hidden;
	z-index:1;
}
DIV.ACT {
	position:absolute;
	height:<%=LayoutTable.layout.height%>;
	width:<%=LayoutTable.layout.width%>;
	margin:0 0 0 0;
	padding:0 0 0 0;
	visibility: hidden;
	z-index:2;
}

DIV.SLIDER-ACT {
	position:absolute;
	top:<%=(kInfoBarHeight + kMenuBarHeight + kStripWidth)%>;
	left:<%=(QSV.window_width - kStripWidth)%>;
	height:<%=SliderPanel.panel_height%>;
	width:<%=kStripWidth%>;
	margin:0 0 0 0;
	padding:0 0 0 0;
	visibility: hidden;
	z-index:2;
}
DIV.SLIDER-IND {
	position:absolute;
	top:<%=(kInfoBarHeight + kMenuBarHeight + kStripWidth)%>;
	left:<%=(QSV.window_width - kStripWidth)%>;
	height:<%=SliderPanel.ind_height%>;
	width:<%=kStripWidth%>;
	margin:0 0 0 0;
	padding:0 0 0 0;
	visibility: hidden;
	z-index:1;
	border-color:#FFAA00;
	border-width:1;
	border-style:solid;
}
LAYER.SLIDER-ACT {
	margin:0 0 0 0;
	padding:0 0 0 0;
}
LAYER.SLIDER-IND {
	margin: 0 0 0 0;
	padding-top:<%=(SliderPanel.ind_height - 8)%>;
	padding-bottom:0;
	padding-left:<%=(kStripWidth - 8)%>;
	padding-right:0;
	border-color:#FFAA00;
	border-width:1;
	border-style:solid;
}

.ANNTEXT {
	font-size:9pt;
	color:#FFAA00;
}

NOBR.BarText {
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
}

TD.MenuButton {
	color: white;
	font-weight: bold;
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
	background-color: #687686;
	padding: 0 7 0 7;
	margin: 0 0 0 0;
}

TD.VarText {
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
	background-color: #304040;
	padding: 0 0 0 2;
	margin: 0 0 0 0;
}

A.DrMenu-item {
	color: white;
	font-weight: bold;
	text-decoration: none;
}

A:hover {
	color:#FFAA00;
}

LAYER.DrMenu-list {
	color: white;
	background-color: #687686;
	border-width: 1 2 2 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
}
DIV.DrMenu-list {
	position: absolute;
	z-index: 4;
 	display:none;
	color: white;
	background-color: #687686;
	border-width: 1 2 2 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
}
NOBR.DrMenu-listItem {
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
}


LAYER.SeriesDetail {
	background-color:#405050;
	border-width: 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
}

DIV.SeriesDetail {
	position: absolute;
	top: 0;
	left: 0;
	z-index:4;
	width: <%=(QSV.window_width - kStripWidth - 2)%>;
/* 	display:none; */
	background-color:#405050;
	border-width: 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
	color:#E0E0C0;
}

/****************************************************************************************/
</STYLE>
<BODY BGCOLOR="black" TEXT="white" onLoad="onFirstLoad()">
<DIV STYLE="width:<%=QSV.window_width%>;height:<%=kMenuBarHeight + kInfoBarHeight%>;">
	<TABLE HEIGHT="<%=kMenuBarHeight%>" ALIGN="CENTER" HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0">
		<TR STYLE="height:<%=kMenuBarHeight%>;">
			<TD STYLE="padding:0 2 0 0;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%LayoutMenu.print_menu_button();%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%OverlayMenu.print_menu_button();%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%ActionMenu.print_menu_button();%>
			<%printVarText("ACTION", "", 32, 36, 5, 7);%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%VOIMenu.print_menu_button();%>
			<%printVarText("WC", " L:", 48, 58, 5, 7);%>
			<%printVarText("WW", " W:", 42, 58, 5, 7);%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%ZoomMenu.print_menu_button();%>
			<%printVarText("ZOOM", "", 90, 108, 12, 21);%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%OrderMenu.print_menu_button();%>
			<%printVarText("ORDER", "", 48, 60, 8, 11);%>
			<TD STYLE="padding:0 0 0 2;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
		</TR>
	</TABLE>
	<TABLE HEIGHT="<%=kInfoBarHeight%>" WIDTH="<%=QSV.window_width%>" ALIGN="CENTER" HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0">
		<TR STYLE="height:<%=kInfoBarHeight%>;">
			<TD NOWRAP ALIGN="CENTER" VALIGN="MIDDLE" CLASS="BAR"><NOBR CLASS="STUDY_INFO"><%print_study_info(DOM);%><%=" "%><%print_study_info_ex(DOM, NumImages);%><%=" "%><%printSeriesDetailButton();%></NOBR></TD>
		</TR>
	</TABLE>
</DIV>
<TABLE ALIGN="LEFT" HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0" BGCOLOR="BLACK" WIDTH="<%=QSV.window_width%>" HEIGHT="<%=QSV.window_height - kInfoBarHeight - kMenuBarHeight%>">
<TR STYLE="height:<%=QSV.window_height - kInfoBarHeight - kMenuBarHeight%>;">
<!-- CANVAS area begin -->
<TD STYLE="width:<%=QSV.window_width - kStripWidth%>;" NOWRAP ALIGN="LEFT" VALIGN="TOP" CLASS="CANVAS"><%printImageTable(LayoutTable.layout, QSV.window_height - kInfoBarHeight - kMenuBarHeight, QSV.window_width - kStripWidth);%></TD>
<!-- CANVAS area end -->
<!-- STRIP area begin -->
<TD STYLE="width:<%=kStripWidth%>;" NOWRAP ALIGN="LEFT" VALIGN="TOP" CLASS="STRIP"><%printStrip(QSV.window_height - kInfoBarHeight - kMenuBarHeight, kStripWidth, NumImages, SliderPanel, QSV);%></TD>
<!-- STRIP area end -->
</TR>
<%
	//===================
	// Workaround for NN
	//  Ȃ LAYER łĂAsĂ܂oOւ̑Ή
	//===================
	if (m_browser.type == "NN") {
		Writer.Write("<TR><TD>\n");
		LayoutMenu.print_menu_list();
		OrderMenu.print_menu_list();
		OverlayMenu.print_menu_list();
		VOIMenu.print_menu_list();
		ZoomMenu.print_menu_list();
		ActionMenu.print_menu_list();
		printSeriesDetail(DOM, QSV);
		Writer.Write("</TD></TR>\n");
	}
%>
</TABLE>
<%
	//===================
	// Workaround for IE
	//  position: absolute; ō DIV Ԃ߂Ă܂ACAEgƂłȂoOւ̑Ή
	//===================
	if (m_browser.type == "IE"
	 || m_browser.type == "GE"
	 || m_browser.type == "OP") {
		LayoutMenu.print_menu_list();
		OrderMenu.print_menu_list();
		OverlayMenu.print_menu_list();
		VOIMenu.print_menu_list();
		ZoomMenu.print_menu_list();
		ActionMenu.print_menu_list();
		printSeriesDetail(DOM, QSV);
	}
	
	//===================
	// Workaround for Mac IE and Gecko
	//  position: absolute; ō DIV Ԃ߂Ă܂ACAEgƂłȂoOւ̑Ή
	//===================
	if ((m_browser.type == "IE" && m_browser.os != "W")
	 || m_browser.type == "GE"
	 || m_browser.type == "OP") {
		Writer.Write("<DIV ID='SLIDER-IND' CLASS='SLIDER-IND'></DIV>\n");
		Writer.Write("<DIV ID='SLIDER-ACT' CLASS='SLIDER-ACT'></DIV>\n");

		UInt32 tableWidth = LayoutTable.layout.cols * LayoutTable.layout.width + kImageSpacing * (LayoutTable.layout.cols - 1);
		UInt32 tableHeight = LayoutTable.layout.rows * LayoutTable.layout.height + kImageSpacing * (LayoutTable.layout.rows - 1);
		UInt32 tableTop = kInfoBarHeight + kMenuBarHeight + (UInt32)Math.Floor((Double)(QSV.window_height - kInfoBarHeight - kMenuBarHeight - tableHeight) / 2);
		UInt32 tableLeft = (UInt32)Math.Floor((Double)(QSV.window_width - kStripWidth - tableWidth) / 2);
	
		UInt32 index = 0;

		UInt32 top = tableTop;
		for (int r = 0; r < LayoutTable.layout.rows; r++) {
			UInt32 left = tableLeft;
			for (int c = 0; c < LayoutTable.layout.cols; c++, index++) {
				Writer.Write("<DIV ID='ANN-" + index + "' CLASS='ANN' STYLE='top:" + top + ";left:" + left + ";'></DIV>\n");
				Writer.Write("<DIV ID='ACT-" + index + "' CLASS='ACT' STYLE='top:" + top + ";left:" + left + ";'></DIV>\n");
				left += LayoutTable.layout.width + kImageSpacing;
			}
			top += LayoutTable.layout.height + kImageSpacing;
		}
	}
%>
<% if (m_browser.type == "NN") { %>
<LAYER ID="ping" TOP="0" LEFT="0"><A HREF="javascript:Reload()"><IMG NAME="ping" SRC="/DIOWave/minilogo.gif" BORDER="0" HSPACE="0" VSPACE="0"></A></LAYER>
<% } else { %>
<DIV STYLE="position:absolute;top:0;left:0;"><A HREF="javascript:Reload()"><IMG NAME="ping" SRC="/DIOWave/minilogo.gif" BORDER="0" HSPACE="0" VSPACE="0"></A></DIV>
<% } %>
</BODY>
</HTML>
